<!--  -->
<template>
  <div style="width: 100%; height: 100%; display: flex">
    <left-tree @click="handleNodeClick"></left-tree>
    <div class="boxright">
      <title-box-vue title="曲线查询">
        <template v-slot:right>
          <div class="titleBoxRightSlot">
            开始/结束日期：
            <fks-date-picker
              v-model="daterange"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              :picker-options="pickerOptions"
            >
            </fks-date-picker>

            <fks-button
              style="margin-left: 10px"
              :disabled="queryDisabled"
              type="primary"
              @click="queryAlarmList"
              >查询</fks-button
            >
          </div>
        </template>
      </title-box-vue>
      <div style="height: calc(100% - 40px)">
        <div id="chartMain" class="chartbox"></div>
      </div>
    </div>
  </div>
</template>
          
     
    
<script>
import { getDay } from "@/utils/istation/common";
import * as echarts from "echarts";
import titleBoxVue from "@/views/main/components/titleBox.vue";
import leftTree from "@/views/main/components/curveQueryLeftTree.vue";

let m_chartMain;
var m_chartValueSeriesList = [];
let m_chartRecordList = [];
let m_alarmList = [];
let m_unitName = "";
let m_recordName = "";

var m_currentPointID = 0;
const testData = {
  Code: 0,
  Message: "\u8BF7\u6C42\u6210\u529F",
  Data: [
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:02:46",
      SrcValue: "94.595",
      DataTime: "2023-01-05 00:00:51",
      DataValue: "0.08968999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:05:45",
      SrcValue: "93.170",
      DataTime: "2023-01-05 00:02:51",
      DataValue: "0.08826500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:07:46",
      SrcValue: "93.099",
      DataTime: "2023-01-05 00:04:53",
      DataValue: "0.088194",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:09:45",
      SrcValue: "92.852",
      DataTime: "2023-01-05 00:06:52",
      DataValue: "0.087947",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:11:46",
      SrcValue: "93.264",
      DataTime: "2023-01-05 00:08:51",
      DataValue: "0.088359",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:13:45",
      SrcValue: "92.746",
      DataTime: "2023-01-05 00:10:51",
      DataValue: "0.087841",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:15:45",
      SrcValue: "93.888",
      DataTime: "2023-01-05 00:12:51",
      DataValue: "0.088983",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:17:46",
      SrcValue: "92.345",
      DataTime: "2023-01-05 00:14:53",
      DataValue: "0.08743999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:19:45",
      SrcValue: "93.358",
      DataTime: "2023-01-05 00:16:51",
      DataValue: "0.088453",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:21:46",
      SrcValue: "93.323",
      DataTime: "2023-01-05 00:18:51",
      DataValue: "0.088418",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:23:45",
      SrcValue: "93.452",
      DataTime: "2023-01-05 00:20:52",
      DataValue: "0.08854699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:25:45",
      SrcValue: "92.969",
      DataTime: "2023-01-05 00:22:51",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:27:45",
      SrcValue: "93.276",
      DataTime: "2023-01-05 00:24:52",
      DataValue: "0.088371",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:29:45",
      SrcValue: "92.958",
      DataTime: "2023-01-05 00:26:51",
      DataValue: "0.08805299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:31:46",
      SrcValue: "93.441",
      DataTime: "2023-01-05 00:28:51",
      DataValue: "0.088536",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:33:46",
      SrcValue: "94.077",
      DataTime: "2023-01-05 00:30:51",
      DataValue: "0.089172",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:35:45",
      SrcValue: "93.582",
      DataTime: "2023-01-05 00:32:53",
      DataValue: "0.088677",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:37:46",
      SrcValue: "94.077",
      DataTime: "2023-01-05 00:34:51",
      DataValue: "0.089172",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:39:46",
      SrcValue: "93.205",
      DataTime: "2023-01-05 00:36:51",
      DataValue: "0.08829999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:41:46",
      SrcValue: "93.499",
      DataTime: "2023-01-05 00:38:52",
      DataValue: "0.088594",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:43:46",
      SrcValue: "93.181",
      DataTime: "2023-01-05 00:40:51",
      DataValue: "0.088276",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:45:45",
      SrcValue: "93.370",
      DataTime: "2023-01-05 00:42:51",
      DataValue: "0.08846500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:47:46",
      SrcValue: "93.346",
      DataTime: "2023-01-05 00:44:51",
      DataValue: "0.08844100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:49:46",
      SrcValue: "93.464",
      DataTime: "2023-01-05 00:46:51",
      DataValue: "0.088559",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:51:43",
      SrcValue: "93.217",
      DataTime: "2023-01-05 00:48:51",
      DataValue: "0.088312",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:53:46",
      SrcValue: "93.393",
      DataTime: "2023-01-05 00:50:51",
      DataValue: "0.08848800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:55:46",
      SrcValue: "93.452",
      DataTime: "2023-01-05 00:52:51",
      DataValue: "0.08854699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:57:46",
      SrcValue: "93.464",
      DataTime: "2023-01-05 00:54:51",
      DataValue: "0.088559",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 00:59:46",
      SrcValue: "93.441",
      DataTime: "2023-01-05 00:56:53",
      DataValue: "0.088536",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:01:46",
      SrcValue: "93.382",
      DataTime: "2023-01-05 00:58:51",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:03:46",
      SrcValue: "93.900",
      DataTime: "2023-01-05 01:00:51",
      DataValue: "0.08899500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:05:44",
      SrcValue: "93.276",
      DataTime: "2023-01-05 01:02:52",
      DataValue: "0.088371",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:07:46",
      SrcValue: "94.241",
      DataTime: "2023-01-05 01:04:53",
      DataValue: "0.089336",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:09:46",
      SrcValue: "93.040",
      DataTime: "2023-01-05 01:06:52",
      DataValue: "0.08813500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:11:46",
      SrcValue: "92.734",
      DataTime: "2023-01-05 01:08:51",
      DataValue: "0.08782899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:13:45",
      SrcValue: "93.335",
      DataTime: "2023-01-05 01:10:52",
      DataValue: "0.08843000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:15:44",
      SrcValue: "93.311",
      DataTime: "2023-01-05 01:12:52",
      DataValue: "0.08840600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:17:46",
      SrcValue: "93.393",
      DataTime: "2023-01-05 01:14:51",
      DataValue: "0.08848800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:19:46",
      SrcValue: "93.028",
      DataTime: "2023-01-05 01:16:51",
      DataValue: "0.088123",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:21:46",
      SrcValue: "92.428",
      DataTime: "2023-01-05 01:18:51",
      DataValue: "0.08752299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:23:46",
      SrcValue: "93.759",
      DataTime: "2023-01-05 01:20:51",
      DataValue: "0.08885400000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:25:46",
      SrcValue: "94.583",
      DataTime: "2023-01-05 01:22:51",
      DataValue: "0.08967800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:27:46",
      SrcValue: "94.006",
      DataTime: "2023-01-05 01:24:51",
      DataValue: "0.08910100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:29:46",
      SrcValue: "93.134",
      DataTime: "2023-01-05 01:26:51",
      DataValue: "0.088229",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:31:45",
      SrcValue: "93.370",
      DataTime: "2023-01-05 01:28:52",
      DataValue: "0.08846500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:33:46",
      SrcValue: "93.441",
      DataTime: "2023-01-05 01:30:51",
      DataValue: "0.088536",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:35:46",
      SrcValue: "94.206",
      DataTime: "2023-01-05 01:32:51",
      DataValue: "0.08930100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:37:46",
      SrcValue: "93.264",
      DataTime: "2023-01-05 01:34:51",
      DataValue: "0.088359",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:39:46",
      SrcValue: "93.429",
      DataTime: "2023-01-05 01:36:51",
      DataValue: "0.08852399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:41:43",
      SrcValue: "93.770",
      DataTime: "2023-01-05 01:38:51",
      DataValue: "0.088865",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:43:46",
      SrcValue: "93.276",
      DataTime: "2023-01-05 01:40:51",
      DataValue: "0.088371",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:45:46",
      SrcValue: "93.570",
      DataTime: "2023-01-05 01:42:52",
      DataValue: "0.088665",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:47:46",
      SrcValue: "93.382",
      DataTime: "2023-01-05 01:44:52",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:49:46",
      SrcValue: "93.040",
      DataTime: "2023-01-05 01:46:51",
      DataValue: "0.08813500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:51:46",
      SrcValue: "93.181",
      DataTime: "2023-01-05 01:48:51",
      DataValue: "0.088276",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:53:46",
      SrcValue: "93.170",
      DataTime: "2023-01-05 01:50:51",
      DataValue: "0.08826500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:55:46",
      SrcValue: "93.841",
      DataTime: "2023-01-05 01:52:51",
      DataValue: "0.08893599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:57:45",
      SrcValue: "93.146",
      DataTime: "2023-01-05 01:54:51",
      DataValue: "0.08824100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 01:59:45",
      SrcValue: "93.229",
      DataTime: "2023-01-05 01:56:52",
      DataValue: "0.08832400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:01:46",
      SrcValue: "93.735",
      DataTime: "2023-01-05 01:58:52",
      DataValue: "0.08882999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:03:46",
      SrcValue: "93.323",
      DataTime: "2023-01-05 02:00:51",
      DataValue: "0.088418",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:05:46",
      SrcValue: "93.335",
      DataTime: "2023-01-05 02:02:51",
      DataValue: "0.08843000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:07:44",
      SrcValue: "93.064",
      DataTime: "2023-01-05 02:04:51",
      DataValue: "0.08815899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:09:46",
      SrcValue: "93.229",
      DataTime: "2023-01-05 02:06:53",
      DataValue: "0.08832400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:11:43",
      SrcValue: "93.382",
      DataTime: "2023-01-05 02:08:51",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:13:44",
      SrcValue: "93.264",
      DataTime: "2023-01-05 02:10:51",
      DataValue: "0.088359",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:15:44",
      SrcValue: "93.075",
      DataTime: "2023-01-05 02:12:52",
      DataValue: "0.08817",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:17:46",
      SrcValue: "93.252",
      DataTime: "2023-01-05 02:14:52",
      DataValue: "0.08834700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:19:46",
      SrcValue: "93.146",
      DataTime: "2023-01-05 02:16:51",
      DataValue: "0.08824100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:21:46",
      SrcValue: "93.405",
      DataTime: "2023-01-05 02:18:52",
      DataValue: "0.0885",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:23:46",
      SrcValue: "93.865",
      DataTime: "2023-01-05 02:20:51",
      DataValue: "0.08895999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:25:45",
      SrcValue: "93.405",
      DataTime: "2023-01-05 02:22:51",
      DataValue: "0.0885",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:27:46",
      SrcValue: "93.393",
      DataTime: "2023-01-05 02:24:51",
      DataValue: "0.08848800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:29:46",
      SrcValue: "94.065",
      DataTime: "2023-01-05 02:26:51",
      DataValue: "0.08915999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:31:46",
      SrcValue: "93.900",
      DataTime: "2023-01-05 02:28:51",
      DataValue: "0.08899500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:33:45",
      SrcValue: "93.323",
      DataTime: "2023-01-05 02:30:52",
      DataValue: "0.088418",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:35:45",
      SrcValue: "93.900",
      DataTime: "2023-01-05 02:32:51",
      DataValue: "0.08899500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:37:46",
      SrcValue: "93.405",
      DataTime: "2023-01-05 02:34:51",
      DataValue: "0.0885",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:39:46",
      SrcValue: "93.323",
      DataTime: "2023-01-05 02:36:51",
      DataValue: "0.088418",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:41:45",
      SrcValue: "93.346",
      DataTime: "2023-01-05 02:38:51",
      DataValue: "0.08844100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:43:46",
      SrcValue: "93.123",
      DataTime: "2023-01-05 02:40:51",
      DataValue: "0.08821800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:45:44",
      SrcValue: "93.947",
      DataTime: "2023-01-05 02:42:51",
      DataValue: "0.08904200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:47:44",
      SrcValue: "92.875",
      DataTime: "2023-01-05 02:44:53",
      DataValue: "0.08796999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:49:46",
      SrcValue: "92.852",
      DataTime: "2023-01-05 02:46:52",
      DataValue: "0.087947",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:51:40",
      SrcValue: "93.393",
      DataTime: "2023-01-05 02:48:51",
      DataValue: "0.08848800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:53:45",
      SrcValue: "93.570",
      DataTime: "2023-01-05 02:50:53",
      DataValue: "0.088665",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:55:46",
      SrcValue: "93.040",
      DataTime: "2023-01-05 02:52:52",
      DataValue: "0.08813500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:57:46",
      SrcValue: "93.287",
      DataTime: "2023-01-05 02:54:51",
      DataValue: "0.08838200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 02:59:45",
      SrcValue: "93.358",
      DataTime: "2023-01-05 02:56:51",
      DataValue: "0.088453",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:01:46",
      SrcValue: "92.510",
      DataTime: "2023-01-05 02:58:51",
      DataValue: "0.08760500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:03:46",
      SrcValue: "93.476",
      DataTime: "2023-01-05 03:00:51",
      DataValue: "0.08857100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:05:46",
      SrcValue: "93.146",
      DataTime: "2023-01-05 03:02:51",
      DataValue: "0.08824100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:07:46",
      SrcValue: "92.993",
      DataTime: "2023-01-05 03:04:51",
      DataValue: "0.088088",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:09:43",
      SrcValue: "92.958",
      DataTime: "2023-01-05 03:06:51",
      DataValue: "0.08805299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:11:46",
      SrcValue: "93.005",
      DataTime: "2023-01-05 03:08:52",
      DataValue: "0.08809999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:13:46",
      SrcValue: "93.794",
      DataTime: "2023-01-05 03:10:51",
      DataValue: "0.088889",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:15:43",
      SrcValue: "92.934",
      DataTime: "2023-01-05 03:12:51",
      DataValue: "0.088029",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:17:46",
      SrcValue: "93.923",
      DataTime: "2023-01-05 03:14:51",
      DataValue: "0.08901800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:19:45",
      SrcValue: "93.441",
      DataTime: "2023-01-05 03:16:51",
      DataValue: "0.088536",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:21:45",
      SrcValue: "93.523",
      DataTime: "2023-01-05 03:18:51",
      DataValue: "0.088618",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:23:46",
      SrcValue: "93.959",
      DataTime: "2023-01-05 03:20:51",
      DataValue: "0.089054",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:25:45",
      SrcValue: "93.641",
      DataTime: "2023-01-05 03:22:51",
      DataValue: "0.08873600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:27:45",
      SrcValue: "94.194",
      DataTime: "2023-01-05 03:24:52",
      DataValue: "0.08928900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:29:46",
      SrcValue: "93.287",
      DataTime: "2023-01-05 03:26:51",
      DataValue: "0.08838200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:31:41",
      SrcValue: "93.417",
      DataTime: "2023-01-05 03:28:53",
      DataValue: "0.08851200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:33:45",
      SrcValue: "93.523",
      DataTime: "2023-01-05 03:30:51",
      DataValue: "0.088618",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:35:44",
      SrcValue: "94.112",
      DataTime: "2023-01-05 03:32:51",
      DataValue: "0.08920700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:37:46",
      SrcValue: "93.535",
      DataTime: "2023-01-05 03:34:52",
      DataValue: "0.08862999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:39:46",
      SrcValue: "93.806",
      DataTime: "2023-01-05 03:36:51",
      DataValue: "0.08890100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:41:46",
      SrcValue: "93.075",
      DataTime: "2023-01-05 03:38:51",
      DataValue: "0.08817",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:43:46",
      SrcValue: "93.417",
      DataTime: "2023-01-05 03:40:51",
      DataValue: "0.08851200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:45:45",
      SrcValue: "93.464",
      DataTime: "2023-01-05 03:42:51",
      DataValue: "0.088559",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:47:46",
      SrcValue: "93.005",
      DataTime: "2023-01-05 03:44:51",
      DataValue: "0.08809999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:49:46",
      SrcValue: "93.853",
      DataTime: "2023-01-05 03:46:51",
      DataValue: "0.088948",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:51:46",
      SrcValue: "92.687",
      DataTime: "2023-01-05 03:48:51",
      DataValue: "0.087782",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:53:46",
      SrcValue: "93.676",
      DataTime: "2023-01-05 03:50:51",
      DataValue: "0.08877100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:55:46",
      SrcValue: "93.028",
      DataTime: "2023-01-05 03:52:51",
      DataValue: "0.088123",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:57:45",
      SrcValue: "94.147",
      DataTime: "2023-01-05 03:54:51",
      DataValue: "0.08924200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 03:59:45",
      SrcValue: "93.429",
      DataTime: "2023-01-05 03:56:52",
      DataValue: "0.08852399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:01:46",
      SrcValue: "93.111",
      DataTime: "2023-01-05 03:58:51",
      DataValue: "0.088206",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:03:46",
      SrcValue: "93.335",
      DataTime: "2023-01-05 04:00:51",
      DataValue: "0.08843000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:05:46",
      SrcValue: "93.276",
      DataTime: "2023-01-05 04:02:53",
      DataValue: "0.088371",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:07:43",
      SrcValue: "93.382",
      DataTime: "2023-01-05 04:04:51",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:09:46",
      SrcValue: "93.052",
      DataTime: "2023-01-05 04:06:51",
      DataValue: "0.088147",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:11:39",
      SrcValue: "93.488",
      DataTime: "2023-01-05 04:08:51",
      DataValue: "0.088583",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:13:45",
      SrcValue: "93.358",
      DataTime: "2023-01-05 04:10:51",
      DataValue: "0.088453",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:15:46",
      SrcValue: "92.451",
      DataTime: "2023-01-05 04:12:52",
      DataValue: "0.08754599999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:17:45",
      SrcValue: "92.640",
      DataTime: "2023-01-05 04:14:52",
      DataValue: "0.08773500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:19:46",
      SrcValue: "93.264",
      DataTime: "2023-01-05 04:16:51",
      DataValue: "0.088359",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:21:45",
      SrcValue: "92.993",
      DataTime: "2023-01-05 04:18:52",
      DataValue: "0.088088",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:23:46",
      SrcValue: "93.311",
      DataTime: "2023-01-05 04:20:53",
      DataValue: "0.08840600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:25:46",
      SrcValue: "93.299",
      DataTime: "2023-01-05 04:22:51",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:27:46",
      SrcValue: "93.676",
      DataTime: "2023-01-05 04:24:51",
      DataValue: "0.08877100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:29:46",
      SrcValue: "93.605",
      DataTime: "2023-01-05 04:26:51",
      DataValue: "0.0887",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:31:46",
      SrcValue: "93.323",
      DataTime: "2023-01-05 04:28:51",
      DataValue: "0.088418",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:33:46",
      SrcValue: "93.429",
      DataTime: "2023-01-05 04:30:54",
      DataValue: "0.08852399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:35:46",
      SrcValue: "93.488",
      DataTime: "2023-01-05 04:32:51",
      DataValue: "0.088583",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:37:46",
      SrcValue: "92.946",
      DataTime: "2023-01-05 04:34:51",
      DataValue: "0.08804100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:39:46",
      SrcValue: "93.982",
      DataTime: "2023-01-05 04:36:51",
      DataValue: "0.08907699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:41:46",
      SrcValue: "93.217",
      DataTime: "2023-01-05 04:38:52",
      DataValue: "0.088312",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:43:46",
      SrcValue: "93.429",
      DataTime: "2023-01-05 04:40:51",
      DataValue: "0.08852399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:45:45",
      SrcValue: "93.382",
      DataTime: "2023-01-05 04:42:51",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:47:46",
      SrcValue: "93.523",
      DataTime: "2023-01-05 04:44:52",
      DataValue: "0.088618",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:49:46",
      SrcValue: "92.357",
      DataTime: "2023-01-05 04:46:51",
      DataValue: "0.087452",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:51:46",
      SrcValue: "93.099",
      DataTime: "2023-01-05 04:48:51",
      DataValue: "0.088194",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:53:46",
      SrcValue: "94.453",
      DataTime: "2023-01-05 04:50:51",
      DataValue: "0.08954800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:55:45",
      SrcValue: "93.299",
      DataTime: "2023-01-05 04:52:52",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:57:45",
      SrcValue: "93.193",
      DataTime: "2023-01-05 04:54:51",
      DataValue: "0.088288",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 04:59:45",
      SrcValue: "93.865",
      DataTime: "2023-01-05 04:56:53",
      DataValue: "0.08895999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:01:46",
      SrcValue: "93.947",
      DataTime: "2023-01-05 04:58:51",
      DataValue: "0.08904200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:03:45",
      SrcValue: "93.111",
      DataTime: "2023-01-05 05:00:51",
      DataValue: "0.088206",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:05:46",
      SrcValue: "93.229",
      DataTime: "2023-01-05 05:02:51",
      DataValue: "0.08832400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:07:46",
      SrcValue: "93.358",
      DataTime: "2023-01-05 05:04:51",
      DataValue: "0.088453",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:09:46",
      SrcValue: "93.558",
      DataTime: "2023-01-05 05:06:52",
      DataValue: "0.08865300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:11:46",
      SrcValue: "93.464",
      DataTime: "2023-01-05 05:08:51",
      DataValue: "0.088559",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:13:46",
      SrcValue: "92.604",
      DataTime: "2023-01-05 05:10:52",
      DataValue: "0.087699",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:15:46",
      SrcValue: "92.675",
      DataTime: "2023-01-05 05:12:51",
      DataValue: "0.08776999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:17:45",
      SrcValue: "92.746",
      DataTime: "2023-01-05 05:14:51",
      DataValue: "0.087841",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:19:46",
      SrcValue: "93.252",
      DataTime: "2023-01-05 05:16:51",
      DataValue: "0.08834700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:21:46",
      SrcValue: "93.653",
      DataTime: "2023-01-05 05:18:51",
      DataValue: "0.08874800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:23:45",
      SrcValue: "93.028",
      DataTime: "2023-01-05 05:20:52",
      DataValue: "0.088123",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:25:46",
      SrcValue: "94.124",
      DataTime: "2023-01-05 05:22:51",
      DataValue: "0.08921899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:27:45",
      SrcValue: "92.863",
      DataTime: "2023-01-05 05:24:51",
      DataValue: "0.08795800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:29:44",
      SrcValue: "93.287",
      DataTime: "2023-01-05 05:26:52",
      DataValue: "0.08838200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:31:43",
      SrcValue: "93.276",
      DataTime: "2023-01-05 05:28:51",
      DataValue: "0.088371",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:33:46",
      SrcValue: "92.604",
      DataTime: "2023-01-05 05:30:51",
      DataValue: "0.087699",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:35:46",
      SrcValue: "93.393",
      DataTime: "2023-01-05 05:32:51",
      DataValue: "0.08848800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:37:46",
      SrcValue: "92.958",
      DataTime: "2023-01-05 05:34:51",
      DataValue: "0.08805299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:39:46",
      SrcValue: "93.358",
      DataTime: "2023-01-05 05:36:51",
      DataValue: "0.088453",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:41:46",
      SrcValue: "94.147",
      DataTime: "2023-01-05 05:38:51",
      DataValue: "0.08924200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:43:45",
      SrcValue: "94.100",
      DataTime: "2023-01-05 05:40:51",
      DataValue: "0.089195",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:45:46",
      SrcValue: "93.382",
      DataTime: "2023-01-05 05:42:53",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:47:46",
      SrcValue: "94.124",
      DataTime: "2023-01-05 05:44:53",
      DataValue: "0.08921899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:49:46",
      SrcValue: "93.535",
      DataTime: "2023-01-05 05:46:51",
      DataValue: "0.08862999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:51:46",
      SrcValue: "93.405",
      DataTime: "2023-01-05 05:48:53",
      DataValue: "0.0885",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:53:45",
      SrcValue: "93.181",
      DataTime: "2023-01-05 05:50:53",
      DataValue: "0.088276",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:55:46",
      SrcValue: "93.323",
      DataTime: "2023-01-05 05:52:51",
      DataValue: "0.088418",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:57:45",
      SrcValue: "93.158",
      DataTime: "2023-01-05 05:54:51",
      DataValue: "0.088253",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 05:59:46",
      SrcValue: "93.240",
      DataTime: "2023-01-05 05:56:51",
      DataValue: "0.088335",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:01:45",
      SrcValue: "94.642",
      DataTime: "2023-01-05 05:58:51",
      DataValue: "0.08973700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:03:44",
      SrcValue: "93.617",
      DataTime: "2023-01-05 06:00:51",
      DataValue: "0.08871200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:05:43",
      SrcValue: "93.570",
      DataTime: "2023-01-05 06:02:51",
      DataValue: "0.088665",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:07:46",
      SrcValue: "93.346",
      DataTime: "2023-01-05 06:04:51",
      DataValue: "0.08844100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:09:39",
      SrcValue: "93.747",
      DataTime: "2023-01-05 06:06:51",
      DataValue: "0.088842",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:11:46",
      SrcValue: "92.593",
      DataTime: "2023-01-05 06:08:51",
      DataValue: "0.08768800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:13:46",
      SrcValue: "94.253",
      DataTime: "2023-01-05 06:10:51",
      DataValue: "0.08934800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:15:44",
      SrcValue: "93.464",
      DataTime: "2023-01-05 06:12:51",
      DataValue: "0.088559",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:17:46",
      SrcValue: "93.123",
      DataTime: "2023-01-05 06:14:51",
      DataValue: "0.08821800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:19:46",
      SrcValue: "93.947",
      DataTime: "2023-01-05 06:16:51",
      DataValue: "0.08904200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:21:46",
      SrcValue: "93.641",
      DataTime: "2023-01-05 06:18:51",
      DataValue: "0.08873600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:23:45",
      SrcValue: "93.499",
      DataTime: "2023-01-05 06:20:52",
      DataValue: "0.088594",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:25:46",
      SrcValue: "92.969",
      DataTime: "2023-01-05 06:22:51",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:27:44",
      SrcValue: "93.476",
      DataTime: "2023-01-05 06:24:51",
      DataValue: "0.08857100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:29:44",
      SrcValue: "93.558",
      DataTime: "2023-01-05 06:26:51",
      DataValue: "0.08865300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:31:46",
      SrcValue: "93.664",
      DataTime: "2023-01-05 06:28:51",
      DataValue: "0.088759",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:33:45",
      SrcValue: "93.358",
      DataTime: "2023-01-05 06:30:51",
      DataValue: "0.088453",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:35:45",
      SrcValue: "93.935",
      DataTime: "2023-01-05 06:32:51",
      DataValue: "0.08903",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:37:45",
      SrcValue: "93.688",
      DataTime: "2023-01-05 06:34:51",
      DataValue: "0.088783",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:39:43",
      SrcValue: "93.641",
      DataTime: "2023-01-05 06:36:52",
      DataValue: "0.08873600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:41:45",
      SrcValue: "96.621",
      DataTime: "2023-01-05 06:38:53",
      DataValue: "0.09171599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:43:46",
      SrcValue: "95.867",
      DataTime: "2023-01-05 06:40:51",
      DataValue: "0.09096200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:45:45",
      SrcValue: "96.043",
      DataTime: "2023-01-05 06:42:51",
      DataValue: "0.091138",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:47:46",
      SrcValue: "96.208",
      DataTime: "2023-01-05 06:44:51",
      DataValue: "0.091303",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:49:46",
      SrcValue: "96.244",
      DataTime: "2023-01-05 06:46:51",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:51:46",
      SrcValue: "95.596",
      DataTime: "2023-01-05 06:48:51",
      DataValue: "0.090691",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:53:46",
      SrcValue: "97.009",
      DataTime: "2023-01-05 06:50:51",
      DataValue: "0.09210399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:55:41",
      SrcValue: "96.173",
      DataTime: "2023-01-05 06:52:52",
      DataValue: "0.09126800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:57:46",
      SrcValue: "96.220",
      DataTime: "2023-01-05 06:54:51",
      DataValue: "0.09131500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 06:59:44",
      SrcValue: "96.032",
      DataTime: "2023-01-05 06:56:51",
      DataValue: "0.09112699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:01:46",
      SrcValue: "96.185",
      DataTime: "2023-01-05 06:58:51",
      DataValue: "0.09128",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:03:45",
      SrcValue: "95.384",
      DataTime: "2023-01-05 07:00:52",
      DataValue: "0.090479",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:05:45",
      SrcValue: "96.562",
      DataTime: "2023-01-05 07:02:52",
      DataValue: "0.09165699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:07:44",
      SrcValue: "96.303",
      DataTime: "2023-01-05 07:04:51",
      DataValue: "0.09139800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:09:46",
      SrcValue: "96.091",
      DataTime: "2023-01-05 07:06:51",
      DataValue: "0.09118599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:11:46",
      SrcValue: "96.338",
      DataTime: "2023-01-05 07:08:54",
      DataValue: "0.09143299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:13:45",
      SrcValue: "96.444",
      DataTime: "2023-01-05 07:10:52",
      DataValue: "0.09153900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:15:45",
      SrcValue: "96.055",
      DataTime: "2023-01-05 07:12:51",
      DataValue: "0.09115000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:17:44",
      SrcValue: "96.161",
      DataTime: "2023-01-05 07:14:51",
      DataValue: "0.091256",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:19:44",
      SrcValue: "96.526",
      DataTime: "2023-01-05 07:16:51",
      DataValue: "0.09162100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:21:42",
      SrcValue: "96.032",
      DataTime: "2023-01-05 07:18:51",
      DataValue: "0.09112699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:23:46",
      SrcValue: "96.220",
      DataTime: "2023-01-05 07:20:51",
      DataValue: "0.09131500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:25:44",
      SrcValue: "96.373",
      DataTime: "2023-01-05 07:22:51",
      DataValue: "0.091468",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:27:45",
      SrcValue: "96.161",
      DataTime: "2023-01-05 07:24:51",
      DataValue: "0.091256",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:29:46",
      SrcValue: "95.584",
      DataTime: "2023-01-05 07:26:53",
      DataValue: "0.09067900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:31:45",
      SrcValue: "96.350",
      DataTime: "2023-01-05 07:28:53",
      DataValue: "0.091445",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:33:46",
      SrcValue: "96.138",
      DataTime: "2023-01-05 07:30:51",
      DataValue: "0.09123300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:35:44",
      SrcValue: "96.738",
      DataTime: "2023-01-05 07:32:51",
      DataValue: "0.091833",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:37:46",
      SrcValue: "95.325",
      DataTime: "2023-01-05 07:34:51",
      DataValue: "0.09042",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:39:46",
      SrcValue: "95.608",
      DataTime: "2023-01-05 07:36:51",
      DataValue: "0.090703",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:41:46",
      SrcValue: "95.443",
      DataTime: "2023-01-05 07:38:51",
      DataValue: "0.09053800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:43:46",
      SrcValue: "96.091",
      DataTime: "2023-01-05 07:40:51",
      DataValue: "0.09118599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:45:43",
      SrcValue: "96.197",
      DataTime: "2023-01-05 07:42:52",
      DataValue: "0.09129200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:47:46",
      SrcValue: "96.361",
      DataTime: "2023-01-05 07:44:53",
      DataValue: "0.09145600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:49:44",
      SrcValue: "95.890",
      DataTime: "2023-01-05 07:46:51",
      DataValue: "0.09098500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:51:43",
      SrcValue: "96.267",
      DataTime: "2023-01-05 07:48:53",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:53:43",
      SrcValue: "96.303",
      DataTime: "2023-01-05 07:50:51",
      DataValue: "0.09139800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:55:45",
      SrcValue: "96.562",
      DataTime: "2023-01-05 07:52:52",
      DataValue: "0.09165699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:57:45",
      SrcValue: "96.208",
      DataTime: "2023-01-05 07:54:51",
      DataValue: "0.091303",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 07:59:45",
      SrcValue: "95.973",
      DataTime: "2023-01-05 07:56:52",
      DataValue: "0.09106800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:01:45",
      SrcValue: "95.513",
      DataTime: "2023-01-05 07:58:51",
      DataValue: "0.090608",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:03:45",
      SrcValue: "95.996",
      DataTime: "2023-01-05 08:00:52",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:05:45",
      SrcValue: "95.843",
      DataTime: "2023-01-05 08:02:51",
      DataValue: "0.09093800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:07:43",
      SrcValue: "96.314",
      DataTime: "2023-01-05 08:04:51",
      DataValue: "0.09140899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:09:45",
      SrcValue: "96.514",
      DataTime: "2023-01-05 08:06:52",
      DataValue: "0.091609",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:11:44",
      SrcValue: "96.903",
      DataTime: "2023-01-05 08:08:51",
      DataValue: "0.091998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:13:45",
      SrcValue: "95.702",
      DataTime: "2023-01-05 08:10:52",
      DataValue: "0.09079699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:15:45",
      SrcValue: "96.938",
      DataTime: "2023-01-05 08:12:52",
      DataValue: "0.092033",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:17:45",
      SrcValue: "96.597",
      DataTime: "2023-01-05 08:14:52",
      DataValue: "0.091692",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:19:44",
      SrcValue: "96.432",
      DataTime: "2023-01-05 08:16:51",
      DataValue: "0.091527",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:21:46",
      SrcValue: "96.621",
      DataTime: "2023-01-05 08:18:52",
      DataValue: "0.09171599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:23:44",
      SrcValue: "95.419",
      DataTime: "2023-01-05 08:20:53",
      DataValue: "0.09051400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:25:45",
      SrcValue: "96.832",
      DataTime: "2023-01-05 08:22:51",
      DataValue: "0.09192700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:27:43",
      SrcValue: "95.961",
      DataTime: "2023-01-05 08:24:51",
      DataValue: "0.091056",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:29:44",
      SrcValue: "96.020",
      DataTime: "2023-01-05 08:26:51",
      DataValue: "0.091115",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:31:46",
      SrcValue: "96.491",
      DataTime: "2023-01-05 08:28:52",
      DataValue: "0.091586",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:33:45",
      SrcValue: "96.091",
      DataTime: "2023-01-05 08:30:51",
      DataValue: "0.09118599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:35:45",
      SrcValue: "96.126",
      DataTime: "2023-01-05 08:32:52",
      DataValue: "0.091221",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:37:44",
      SrcValue: "95.007",
      DataTime: "2023-01-05 08:34:53",
      DataValue: "0.09010200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:39:45",
      SrcValue: "96.020",
      DataTime: "2023-01-05 08:36:53",
      DataValue: "0.091115",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:41:46",
      SrcValue: "97.150",
      DataTime: "2023-01-05 08:38:51",
      DataValue: "0.09224500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:43:44",
      SrcValue: "96.197",
      DataTime: "2023-01-05 08:40:51",
      DataValue: "0.09129200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:45:44",
      SrcValue: "95.996",
      DataTime: "2023-01-05 08:42:51",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:47:44",
      SrcValue: "96.138",
      DataTime: "2023-01-05 08:44:51",
      DataValue: "0.09123300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:49:45",
      SrcValue: "96.503",
      DataTime: "2023-01-05 08:46:53",
      DataValue: "0.09159800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:51:46",
      SrcValue: "95.890",
      DataTime: "2023-01-05 08:48:51",
      DataValue: "0.09098500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:53:44",
      SrcValue: "96.043",
      DataTime: "2023-01-05 08:50:53",
      DataValue: "0.091138",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:55:45",
      SrcValue: "95.513",
      DataTime: "2023-01-05 08:52:52",
      DataValue: "0.090608",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:57:44",
      SrcValue: "97.044",
      DataTime: "2023-01-05 08:54:53",
      DataValue: "0.092139",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 08:59:45",
      SrcValue: "96.232",
      DataTime: "2023-01-05 08:56:51",
      DataValue: "0.09132699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:01:43",
      SrcValue: "96.161",
      DataTime: "2023-01-05 08:58:51",
      DataValue: "0.091256",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:03:45",
      SrcValue: "96.656",
      DataTime: "2023-01-05 09:00:51",
      DataValue: "0.091751",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:05:45",
      SrcValue: "95.937",
      DataTime: "2023-01-05 09:02:51",
      DataValue: "0.091032",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:07:45",
      SrcValue: "96.538",
      DataTime: "2023-01-05 09:04:51",
      DataValue: "0.09163299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:09:45",
      SrcValue: "96.715",
      DataTime: "2023-01-05 09:06:51",
      DataValue: "0.09181",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:11:44",
      SrcValue: "96.373",
      DataTime: "2023-01-05 09:08:51",
      DataValue: "0.091468",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:13:42",
      SrcValue: "96.397",
      DataTime: "2023-01-05 09:10:51",
      DataValue: "0.09149200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:15:45",
      SrcValue: "96.326",
      DataTime: "2023-01-05 09:12:52",
      DataValue: "0.091421",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:17:45",
      SrcValue: "97.103",
      DataTime: "2023-01-05 09:14:53",
      DataValue: "0.092198",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:19:45",
      SrcValue: "95.490",
      DataTime: "2023-01-05 09:16:53",
      DataValue: "0.090585",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:21:45",
      SrcValue: "96.609",
      DataTime: "2023-01-05 09:18:52",
      DataValue: "0.09170400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:23:45",
      SrcValue: "96.456",
      DataTime: "2023-01-05 09:20:51",
      DataValue: "0.091551",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:25:45",
      SrcValue: "96.408",
      DataTime: "2023-01-05 09:22:51",
      DataValue: "0.091503",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:27:45",
      SrcValue: "96.361",
      DataTime: "2023-01-05 09:24:51",
      DataValue: "0.09145600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:29:45",
      SrcValue: "96.361",
      DataTime: "2023-01-05 09:26:52",
      DataValue: "0.09145600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:31:45",
      SrcValue: "96.255",
      DataTime: "2023-01-05 09:28:51",
      DataValue: "0.09134999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:33:42",
      SrcValue: "96.314",
      DataTime: "2023-01-05 09:30:51",
      DataValue: "0.09140899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:35:45",
      SrcValue: "96.974",
      DataTime: "2023-01-05 09:32:51",
      DataValue: "0.09206900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:37:41",
      SrcValue: "96.291",
      DataTime: "2023-01-05 09:34:51",
      DataValue: "0.091386",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:39:44",
      SrcValue: "96.408",
      DataTime: "2023-01-05 09:36:51",
      DataValue: "0.091503",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:41:45",
      SrcValue: "96.350",
      DataTime: "2023-01-05 09:38:51",
      DataValue: "0.091445",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:43:42",
      SrcValue: "96.138",
      DataTime: "2023-01-05 09:40:51",
      DataValue: "0.09123300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:45:45",
      SrcValue: "96.291",
      DataTime: "2023-01-05 09:42:51",
      DataValue: "0.091386",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:47:42",
      SrcValue: "96.232",
      DataTime: "2023-01-05 09:44:52",
      DataValue: "0.09132699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:49:45",
      SrcValue: "96.244",
      DataTime: "2023-01-05 09:46:51",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:51:45",
      SrcValue: "96.621",
      DataTime: "2023-01-05 09:48:51",
      DataValue: "0.09171599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:53:42",
      SrcValue: "96.420",
      DataTime: "2023-01-05 09:50:52",
      DataValue: "0.09151500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:55:44",
      SrcValue: "96.232",
      DataTime: "2023-01-05 09:52:51",
      DataValue: "0.09132699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:57:45",
      SrcValue: "96.126",
      DataTime: "2023-01-05 09:54:51",
      DataValue: "0.091221",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 09:59:44",
      SrcValue: "95.996",
      DataTime: "2023-01-05 09:56:51",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:01:44",
      SrcValue: "96.491",
      DataTime: "2023-01-05 09:58:51",
      DataValue: "0.091586",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:03:44",
      SrcValue: "96.279",
      DataTime: "2023-01-05 10:00:51",
      DataValue: "0.09137400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:05:45",
      SrcValue: "96.809",
      DataTime: "2023-01-05 10:02:51",
      DataValue: "0.09190400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:07:44",
      SrcValue: "96.173",
      DataTime: "2023-01-05 10:04:53",
      DataValue: "0.09126800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:09:42",
      SrcValue: "96.338",
      DataTime: "2023-01-05 10:06:51",
      DataValue: "0.09143299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:11:43",
      SrcValue: "96.173",
      DataTime: "2023-01-05 10:08:51",
      DataValue: "0.09126800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:13:44",
      SrcValue: "96.091",
      DataTime: "2023-01-05 10:10:51",
      DataValue: "0.09118599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:15:45",
      SrcValue: "96.114",
      DataTime: "2023-01-05 10:12:51",
      DataValue: "0.09120900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:17:45",
      SrcValue: "96.197",
      DataTime: "2023-01-05 10:14:51",
      DataValue: "0.09129200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:19:44",
      SrcValue: "95.914",
      DataTime: "2023-01-05 10:16:51",
      DataValue: "0.091009",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:21:38",
      SrcValue: "96.008",
      DataTime: "2023-01-05 10:18:51",
      DataValue: "0.09110299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:23:44",
      SrcValue: "96.173",
      DataTime: "2023-01-05 10:20:51",
      DataValue: "0.09126800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:25:44",
      SrcValue: "96.255",
      DataTime: "2023-01-05 10:22:51",
      DataValue: "0.09134999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:27:44",
      SrcValue: "96.032",
      DataTime: "2023-01-05 10:24:52",
      DataValue: "0.09112699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:29:45",
      SrcValue: "97.092",
      DataTime: "2023-01-05 10:26:51",
      DataValue: "0.09218699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:31:45",
      SrcValue: "96.938",
      DataTime: "2023-01-05 10:28:51",
      DataValue: "0.092033",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:33:45",
      SrcValue: "96.079",
      DataTime: "2023-01-05 10:30:52",
      DataValue: "0.091174",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:35:45",
      SrcValue: "96.091",
      DataTime: "2023-01-05 10:32:51",
      DataValue: "0.09118599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:37:45",
      SrcValue: "96.314",
      DataTime: "2023-01-05 10:34:51",
      DataValue: "0.09140899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:39:45",
      SrcValue: "95.337",
      DataTime: "2023-01-05 10:36:51",
      DataValue: "0.09043200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:41:43",
      SrcValue: "96.055",
      DataTime: "2023-01-05 10:38:51",
      DataValue: "0.09115000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:43:44",
      SrcValue: "95.843",
      DataTime: "2023-01-05 10:40:51",
      DataValue: "0.09093800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:45:45",
      SrcValue: "96.891",
      DataTime: "2023-01-05 10:42:51",
      DataValue: "0.09198600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:47:45",
      SrcValue: "96.102",
      DataTime: "2023-01-05 10:44:51",
      DataValue: "0.091197",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:49:45",
      SrcValue: "95.360",
      DataTime: "2023-01-05 10:46:51",
      DataValue: "0.09045500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:51:45",
      SrcValue: "95.890",
      DataTime: "2023-01-05 10:48:51",
      DataValue: "0.09098500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:53:45",
      SrcValue: "96.267",
      DataTime: "2023-01-05 10:50:51",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:55:45",
      SrcValue: "96.208",
      DataTime: "2023-01-05 10:52:52",
      DataValue: "0.091303",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:57:44",
      SrcValue: "96.267",
      DataTime: "2023-01-05 10:54:51",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 10:59:45",
      SrcValue: "96.880",
      DataTime: "2023-01-05 10:56:51",
      DataValue: "0.091975",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:01:45",
      SrcValue: "96.597",
      DataTime: "2023-01-05 10:58:51",
      DataValue: "0.091692",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:03:44",
      SrcValue: "96.020",
      DataTime: "2023-01-05 11:00:51",
      DataValue: "0.091115",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:05:45",
      SrcValue: "95.867",
      DataTime: "2023-01-05 11:02:51",
      DataValue: "0.09096200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:07:44",
      SrcValue: "96.267",
      DataTime: "2023-01-05 11:04:51",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:09:45",
      SrcValue: "95.949",
      DataTime: "2023-01-05 11:06:51",
      DataValue: "0.09104400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:11:45",
      SrcValue: "95.820",
      DataTime: "2023-01-05 11:08:51",
      DataValue: "0.090915",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:13:45",
      SrcValue: "96.644",
      DataTime: "2023-01-05 11:10:51",
      DataValue: "0.09173900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:15:45",
      SrcValue: "96.149",
      DataTime: "2023-01-05 11:12:51",
      DataValue: "0.09124399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:17:45",
      SrcValue: "97.080",
      DataTime: "2023-01-05 11:14:51",
      DataValue: "0.092175",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:19:40",
      SrcValue: "95.985",
      DataTime: "2023-01-05 11:16:51",
      DataValue: "0.09108",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:21:45",
      SrcValue: "95.879",
      DataTime: "2023-01-05 11:18:51",
      DataValue: "0.090974",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:23:44",
      SrcValue: "96.067",
      DataTime: "2023-01-05 11:20:53",
      DataValue: "0.09116199999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:25:45",
      SrcValue: "97.280",
      DataTime: "2023-01-05 11:22:53",
      DataValue: "0.09237500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:27:44",
      SrcValue: "96.173",
      DataTime: "2023-01-05 11:24:52",
      DataValue: "0.09126800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:29:45",
      SrcValue: "96.997",
      DataTime: "2023-01-05 11:26:53",
      DataValue: "0.09209200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:31:45",
      SrcValue: "96.291",
      DataTime: "2023-01-05 11:28:51",
      DataValue: "0.091386",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:33:45",
      SrcValue: "96.267",
      DataTime: "2023-01-05 11:30:51",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:35:45",
      SrcValue: "95.207",
      DataTime: "2023-01-05 11:32:52",
      DataValue: "0.090302",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:37:45",
      SrcValue: "95.843",
      DataTime: "2023-01-05 11:34:52",
      DataValue: "0.09093800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:39:45",
      SrcValue: "96.809",
      DataTime: "2023-01-05 11:36:51",
      DataValue: "0.09190400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:41:44",
      SrcValue: "95.631",
      DataTime: "2023-01-05 11:38:51",
      DataValue: "0.090726",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:43:44",
      SrcValue: "95.808",
      DataTime: "2023-01-05 11:40:51",
      DataValue: "0.09090300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:45:45",
      SrcValue: "95.725",
      DataTime: "2023-01-05 11:42:51",
      DataValue: "0.09081999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:47:44",
      SrcValue: "95.725",
      DataTime: "2023-01-05 11:44:51",
      DataValue: "0.09081999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:49:45",
      SrcValue: "96.020",
      DataTime: "2023-01-05 11:46:51",
      DataValue: "0.091115",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:51:45",
      SrcValue: "95.443",
      DataTime: "2023-01-05 11:48:51",
      DataValue: "0.09053800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:53:44",
      SrcValue: "95.137",
      DataTime: "2023-01-05 11:50:51",
      DataValue: "0.090232",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:55:42",
      SrcValue: "95.961",
      DataTime: "2023-01-05 11:52:51",
      DataValue: "0.091056",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:57:42",
      SrcValue: "95.466",
      DataTime: "2023-01-05 11:54:51",
      DataValue: "0.090561",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 11:59:43",
      SrcValue: "95.466",
      DataTime: "2023-01-05 11:56:51",
      DataValue: "0.090561",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:01:45",
      SrcValue: "95.631",
      DataTime: "2023-01-05 11:58:52",
      DataValue: "0.090726",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:03:44",
      SrcValue: "96.291",
      DataTime: "2023-01-05 12:00:51",
      DataValue: "0.091386",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:05:45",
      SrcValue: "95.549",
      DataTime: "2023-01-05 12:02:53",
      DataValue: "0.090644",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:07:45",
      SrcValue: "95.761",
      DataTime: "2023-01-05 12:04:53",
      DataValue: "0.09085599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:09:45",
      SrcValue: "97.056",
      DataTime: "2023-01-05 12:06:51",
      DataValue: "0.09215100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:11:43",
      SrcValue: "95.596",
      DataTime: "2023-01-05 12:08:51",
      DataValue: "0.090691",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:13:45",
      SrcValue: "95.619",
      DataTime: "2023-01-05 12:10:51",
      DataValue: "0.09071399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:15:41",
      SrcValue: "95.749",
      DataTime: "2023-01-05 12:12:51",
      DataValue: "0.09084400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:17:45",
      SrcValue: "95.290",
      DataTime: "2023-01-05 12:14:51",
      DataValue: "0.09038500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:19:41",
      SrcValue: "95.937",
      DataTime: "2023-01-05 12:16:51",
      DataValue: "0.091032",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:21:45",
      SrcValue: "95.007",
      DataTime: "2023-01-05 12:18:52",
      DataValue: "0.09010200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:23:45",
      SrcValue: "96.267",
      DataTime: "2023-01-05 12:20:53",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:25:45",
      SrcValue: "95.631",
      DataTime: "2023-01-05 12:22:52",
      DataValue: "0.090726",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:27:45",
      SrcValue: "95.926",
      DataTime: "2023-01-05 12:24:52",
      DataValue: "0.09102099999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:29:45",
      SrcValue: "95.419",
      DataTime: "2023-01-05 12:26:51",
      DataValue: "0.09051400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:31:45",
      SrcValue: "95.655",
      DataTime: "2023-01-05 12:28:52",
      DataValue: "0.09075",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:33:45",
      SrcValue: "95.690",
      DataTime: "2023-01-05 12:30:51",
      DataValue: "0.090785",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:35:44",
      SrcValue: "95.702",
      DataTime: "2023-01-05 12:32:51",
      DataValue: "0.09079699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:37:45",
      SrcValue: "95.513",
      DataTime: "2023-01-05 12:34:51",
      DataValue: "0.090608",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:39:45",
      SrcValue: "95.843",
      DataTime: "2023-01-05 12:36:52",
      DataValue: "0.09093800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:41:44",
      SrcValue: "95.478",
      DataTime: "2023-01-05 12:38:51",
      DataValue: "0.09057299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:43:45",
      SrcValue: "95.855",
      DataTime: "2023-01-05 12:40:51",
      DataValue: "0.09095",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:45:45",
      SrcValue: "86.610",
      DataTime: "2023-01-05 12:42:51",
      DataValue: "0.081705",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:47:45",
      SrcValue: "85.008",
      DataTime: "2023-01-05 12:44:51",
      DataValue: "0.08010300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:49:45",
      SrcValue: "85.597",
      DataTime: "2023-01-05 12:46:51",
      DataValue: "0.08069199999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:51:45",
      SrcValue: "86.268",
      DataTime: "2023-01-05 12:48:51",
      DataValue: "0.08136299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:53:45",
      SrcValue: "93.252",
      DataTime: "2023-01-05 12:50:51",
      DataValue: "0.08834700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:55:45",
      SrcValue: "97.987",
      DataTime: "2023-01-05 12:52:51",
      DataValue: "0.093082",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:57:45",
      SrcValue: "96.244",
      DataTime: "2023-01-05 12:54:51",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 12:59:45",
      SrcValue: "96.397",
      DataTime: "2023-01-05 12:56:51",
      DataValue: "0.09149200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:01:45",
      SrcValue: "95.949",
      DataTime: "2023-01-05 12:58:51",
      DataValue: "0.09104400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:03:45",
      SrcValue: "96.456",
      DataTime: "2023-01-05 13:00:51",
      DataValue: "0.091551",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:05:44",
      SrcValue: "95.820",
      DataTime: "2023-01-05 13:02:51",
      DataValue: "0.090915",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:07:45",
      SrcValue: "96.832",
      DataTime: "2023-01-05 13:04:51",
      DataValue: "0.09192700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:09:45",
      SrcValue: "95.820",
      DataTime: "2023-01-05 13:06:52",
      DataValue: "0.090915",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:11:44",
      SrcValue: "95.643",
      DataTime: "2023-01-05 13:08:51",
      DataValue: "0.09073800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:13:44",
      SrcValue: "95.596",
      DataTime: "2023-01-05 13:10:52",
      DataValue: "0.090691",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:15:45",
      SrcValue: "95.773",
      DataTime: "2023-01-05 13:12:51",
      DataValue: "0.090868",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:17:45",
      SrcValue: "95.007",
      DataTime: "2023-01-05 13:14:52",
      DataValue: "0.09010200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:19:45",
      SrcValue: "95.337",
      DataTime: "2023-01-05 13:16:51",
      DataValue: "0.09043200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:21:43",
      SrcValue: "96.032",
      DataTime: "2023-01-05 13:18:51",
      DataValue: "0.09112699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:23:45",
      SrcValue: "95.243",
      DataTime: "2023-01-05 13:20:51",
      DataValue: "0.090338",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:25:45",
      SrcValue: "95.820",
      DataTime: "2023-01-05 13:22:52",
      DataValue: "0.090915",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:27:45",
      SrcValue: "95.831",
      DataTime: "2023-01-05 13:24:51",
      DataValue: "0.090926",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:29:44",
      SrcValue: "95.761",
      DataTime: "2023-01-05 13:26:51",
      DataValue: "0.09085599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:31:45",
      SrcValue: "97.080",
      DataTime: "2023-01-05 13:28:51",
      DataValue: "0.092175",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:33:43",
      SrcValue: "95.996",
      DataTime: "2023-01-05 13:30:51",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:35:44",
      SrcValue: "95.678",
      DataTime: "2023-01-05 13:32:51",
      DataValue: "0.09077299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:37:45",
      SrcValue: "95.914",
      DataTime: "2023-01-05 13:34:51",
      DataValue: "0.091009",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:39:45",
      SrcValue: "95.396",
      DataTime: "2023-01-05 13:36:52",
      DataValue: "0.09049100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:41:45",
      SrcValue: "95.443",
      DataTime: "2023-01-05 13:38:51",
      DataValue: "0.09053800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:43:45",
      SrcValue: "95.926",
      DataTime: "2023-01-05 13:40:51",
      DataValue: "0.09102099999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:45:44",
      SrcValue: "96.986",
      DataTime: "2023-01-05 13:42:52",
      DataValue: "0.092081",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:47:45",
      SrcValue: "95.749",
      DataTime: "2023-01-05 13:44:51",
      DataValue: "0.09084400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:49:45",
      SrcValue: "94.936",
      DataTime: "2023-01-05 13:46:53",
      DataValue: "0.090031",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:51:44",
      SrcValue: "95.831",
      DataTime: "2023-01-05 13:48:51",
      DataValue: "0.090926",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:53:45",
      SrcValue: "95.843",
      DataTime: "2023-01-05 13:50:51",
      DataValue: "0.09093800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:55:45",
      SrcValue: "95.761",
      DataTime: "2023-01-05 13:52:51",
      DataValue: "0.09085599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:57:44",
      SrcValue: "95.796",
      DataTime: "2023-01-05 13:54:51",
      DataValue: "0.090891",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 13:59:45",
      SrcValue: "95.631",
      DataTime: "2023-01-05 13:56:51",
      DataValue: "0.090726",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:01:45",
      SrcValue: "95.219",
      DataTime: "2023-01-05 13:58:52",
      DataValue: "0.090314",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:03:45",
      SrcValue: "96.173",
      DataTime: "2023-01-05 14:00:53",
      DataValue: "0.09126800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:05:45",
      SrcValue: "95.490",
      DataTime: "2023-01-05 14:02:51",
      DataValue: "0.090585",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:07:44",
      SrcValue: "95.584",
      DataTime: "2023-01-05 14:04:53",
      DataValue: "0.09067900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:09:40",
      SrcValue: "95.796",
      DataTime: "2023-01-05 14:06:51",
      DataValue: "0.090891",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:11:44",
      SrcValue: "95.725",
      DataTime: "2023-01-05 14:08:51",
      DataValue: "0.09081999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:13:45",
      SrcValue: "95.867",
      DataTime: "2023-01-05 14:10:51",
      DataValue: "0.09096200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:15:45",
      SrcValue: "95.808",
      DataTime: "2023-01-05 14:12:52",
      DataValue: "0.09090300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:17:45",
      SrcValue: "96.314",
      DataTime: "2023-01-05 14:14:51",
      DataValue: "0.09140899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:19:44",
      SrcValue: "95.419",
      DataTime: "2023-01-05 14:16:51",
      DataValue: "0.09051400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:21:45",
      SrcValue: "95.749",
      DataTime: "2023-01-05 14:18:51",
      DataValue: "0.09084400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:23:45",
      SrcValue: "95.537",
      DataTime: "2023-01-05 14:20:52",
      DataValue: "0.09063200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:25:45",
      SrcValue: "95.808",
      DataTime: "2023-01-05 14:22:51",
      DataValue: "0.09090300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:27:44",
      SrcValue: "96.232",
      DataTime: "2023-01-05 14:24:53",
      DataValue: "0.09132699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:29:44",
      SrcValue: "96.067",
      DataTime: "2023-01-05 14:26:51",
      DataValue: "0.09116199999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:31:45",
      SrcValue: "95.631",
      DataTime: "2023-01-05 14:28:51",
      DataValue: "0.090726",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:33:45",
      SrcValue: "95.690",
      DataTime: "2023-01-05 14:30:51",
      DataValue: "0.090785",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:35:45",
      SrcValue: "95.596",
      DataTime: "2023-01-05 14:32:52",
      DataValue: "0.090691",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:37:44",
      SrcValue: "95.926",
      DataTime: "2023-01-05 14:34:51",
      DataValue: "0.09102099999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:39:45",
      SrcValue: "96.538",
      DataTime: "2023-01-05 14:36:51",
      DataValue: "0.09163299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:41:44",
      SrcValue: "96.244",
      DataTime: "2023-01-05 14:38:51",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:43:45",
      SrcValue: "95.855",
      DataTime: "2023-01-05 14:40:51",
      DataValue: "0.09095",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:45:44",
      SrcValue: "95.902",
      DataTime: "2023-01-05 14:42:51",
      DataValue: "0.090997",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:47:43",
      SrcValue: "95.879",
      DataTime: "2023-01-05 14:44:52",
      DataValue: "0.090974",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:49:45",
      SrcValue: "96.903",
      DataTime: "2023-01-05 14:46:51",
      DataValue: "0.091998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:51:45",
      SrcValue: "96.114",
      DataTime: "2023-01-05 14:48:51",
      DataValue: "0.09120900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:53:42",
      SrcValue: "96.149",
      DataTime: "2023-01-05 14:50:52",
      DataValue: "0.09124399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:55:45",
      SrcValue: "95.926",
      DataTime: "2023-01-05 14:52:51",
      DataValue: "0.09102099999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:57:45",
      SrcValue: "96.338",
      DataTime: "2023-01-05 14:54:51",
      DataValue: "0.09143299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 14:59:42",
      SrcValue: "96.126",
      DataTime: "2023-01-05 14:56:51",
      DataValue: "0.091221",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:01:42",
      SrcValue: "96.255",
      DataTime: "2023-01-05 14:58:51",
      DataValue: "0.09134999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:03:45",
      SrcValue: "97.374",
      DataTime: "2023-01-05 15:00:51",
      DataValue: "0.092469",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:05:44",
      SrcValue: "96.126",
      DataTime: "2023-01-05 15:02:51",
      DataValue: "0.091221",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:07:45",
      SrcValue: "96.208",
      DataTime: "2023-01-05 15:04:51",
      DataValue: "0.091303",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:09:41",
      SrcValue: "96.303",
      DataTime: "2023-01-05 15:06:52",
      DataValue: "0.09139800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:11:45",
      SrcValue: "96.161",
      DataTime: "2023-01-05 15:08:51",
      DataValue: "0.091256",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:13:45",
      SrcValue: "96.055",
      DataTime: "2023-01-05 15:10:51",
      DataValue: "0.09115000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:15:45",
      SrcValue: "96.279",
      DataTime: "2023-01-05 15:12:51",
      DataValue: "0.09137400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:17:45",
      SrcValue: "96.255",
      DataTime: "2023-01-05 15:14:53",
      DataValue: "0.09134999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:19:44",
      SrcValue: "96.255",
      DataTime: "2023-01-05 15:16:51",
      DataValue: "0.09134999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:21:45",
      SrcValue: "95.113",
      DataTime: "2023-01-05 15:18:52",
      DataValue: "0.09020800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:23:45",
      SrcValue: "96.244",
      DataTime: "2023-01-05 15:20:51",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:25:42",
      SrcValue: "96.149",
      DataTime: "2023-01-05 15:22:51",
      DataValue: "0.09124399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:27:45",
      SrcValue: "96.326",
      DataTime: "2023-01-05 15:24:51",
      DataValue: "0.091421",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:29:41",
      SrcValue: "96.232",
      DataTime: "2023-01-05 15:26:51",
      DataValue: "0.09132699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:31:45",
      SrcValue: "96.220",
      DataTime: "2023-01-05 15:28:52",
      DataValue: "0.09131500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:33:45",
      SrcValue: "96.974",
      DataTime: "2023-01-05 15:30:51",
      DataValue: "0.09206900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:35:43",
      SrcValue: "96.197",
      DataTime: "2023-01-05 15:32:51",
      DataValue: "0.09129200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:37:45",
      SrcValue: "96.161",
      DataTime: "2023-01-05 15:34:53",
      DataValue: "0.091256",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:39:44",
      SrcValue: "96.079",
      DataTime: "2023-01-05 15:36:51",
      DataValue: "0.091174",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:41:43",
      SrcValue: "96.114",
      DataTime: "2023-01-05 15:38:52",
      DataValue: "0.09120900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:43:42",
      SrcValue: "96.244",
      DataTime: "2023-01-05 15:40:51",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:45:44",
      SrcValue: "96.149",
      DataTime: "2023-01-05 15:42:51",
      DataValue: "0.09124399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:47:43",
      SrcValue: "96.244",
      DataTime: "2023-01-05 15:44:52",
      DataValue: "0.091339",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:49:45",
      SrcValue: "95.407",
      DataTime: "2023-01-05 15:46:51",
      DataValue: "0.090502",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:51:45",
      SrcValue: "95.843",
      DataTime: "2023-01-05 15:48:51",
      DataValue: "0.09093800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:53:45",
      SrcValue: "96.291",
      DataTime: "2023-01-05 15:50:51",
      DataValue: "0.091386",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:55:44",
      SrcValue: "95.054",
      DataTime: "2023-01-05 15:52:52",
      DataValue: "0.090149",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:57:45",
      SrcValue: "95.431",
      DataTime: "2023-01-05 15:54:51",
      DataValue: "0.090526",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 15:59:45",
      SrcValue: "96.114",
      DataTime: "2023-01-05 15:56:51",
      DataValue: "0.09120900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:01:45",
      SrcValue: "95.996",
      DataTime: "2023-01-05 15:58:52",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:03:44",
      SrcValue: "96.715",
      DataTime: "2023-01-05 16:00:53",
      DataValue: "0.09181",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:05:41",
      SrcValue: "96.055",
      DataTime: "2023-01-05 16:02:51",
      DataValue: "0.09115000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:07:45",
      SrcValue: "96.185",
      DataTime: "2023-01-05 16:04:51",
      DataValue: "0.09128",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:09:43",
      SrcValue: "95.973",
      DataTime: "2023-01-05 16:06:51",
      DataValue: "0.09106800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:11:43",
      SrcValue: "95.996",
      DataTime: "2023-01-05 16:08:51",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:13:45",
      SrcValue: "96.267",
      DataTime: "2023-01-05 16:10:51",
      DataValue: "0.091362",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:15:44",
      SrcValue: "95.996",
      DataTime: "2023-01-05 16:12:51",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:17:45",
      SrcValue: "96.397",
      DataTime: "2023-01-05 16:14:51",
      DataValue: "0.09149200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:19:45",
      SrcValue: "95.537",
      DataTime: "2023-01-05 16:16:52",
      DataValue: "0.09063200000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:21:43",
      SrcValue: "96.055",
      DataTime: "2023-01-05 16:18:51",
      DataValue: "0.09115000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:23:44",
      SrcValue: "95.808",
      DataTime: "2023-01-05 16:20:51",
      DataValue: "0.09090300000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:25:44",
      SrcValue: "95.360",
      DataTime: "2023-01-05 16:22:51",
      DataValue: "0.09045500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:27:44",
      SrcValue: "95.725",
      DataTime: "2023-01-05 16:24:52",
      DataValue: "0.09081999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:29:45",
      SrcValue: "92.345",
      DataTime: "2023-01-05 16:26:51",
      DataValue: "0.08743999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:31:45",
      SrcValue: "92.816",
      DataTime: "2023-01-05 16:28:51",
      DataValue: "0.08791100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:33:43",
      SrcValue: "92.875",
      DataTime: "2023-01-05 16:30:52",
      DataValue: "0.08796999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:35:45",
      SrcValue: "93.028",
      DataTime: "2023-01-05 16:32:51",
      DataValue: "0.088123",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:37:43",
      SrcValue: "93.193",
      DataTime: "2023-01-05 16:34:52",
      DataValue: "0.088288",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:39:45",
      SrcValue: "93.912",
      DataTime: "2023-01-05 16:36:51",
      DataValue: "0.089007",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:41:45",
      SrcValue: "93.947",
      DataTime: "2023-01-05 16:38:51",
      DataValue: "0.08904200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:43:45",
      SrcValue: "92.510",
      DataTime: "2023-01-05 16:40:52",
      DataValue: "0.08760500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:45:45",
      SrcValue: "92.887",
      DataTime: "2023-01-05 16:42:51",
      DataValue: "0.087982",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:47:44",
      SrcValue: "92.969",
      DataTime: "2023-01-05 16:44:53",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:49:45",
      SrcValue: "93.040",
      DataTime: "2023-01-05 16:46:52",
      DataValue: "0.08813500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:51:45",
      SrcValue: "92.357",
      DataTime: "2023-01-05 16:48:51",
      DataValue: "0.087452",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:53:45",
      SrcValue: "94.053",
      DataTime: "2023-01-05 16:50:51",
      DataValue: "0.089148",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:55:45",
      SrcValue: "93.229",
      DataTime: "2023-01-05 16:52:51",
      DataValue: "0.08832400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:57:45",
      SrcValue: "92.651",
      DataTime: "2023-01-05 16:54:53",
      DataValue: "0.08774599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 16:59:45",
      SrcValue: "93.170",
      DataTime: "2023-01-05 16:56:53",
      DataValue: "0.08826500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:01:45",
      SrcValue: "92.828",
      DataTime: "2023-01-05 16:58:52",
      DataValue: "0.087923",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:03:45",
      SrcValue: "92.875",
      DataTime: "2023-01-05 17:00:52",
      DataValue: "0.08796999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:05:41",
      SrcValue: "93.134",
      DataTime: "2023-01-05 17:02:51",
      DataValue: "0.088229",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:07:45",
      SrcValue: "92.863",
      DataTime: "2023-01-05 17:04:51",
      DataValue: "0.08795800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:09:44",
      SrcValue: "92.675",
      DataTime: "2023-01-05 17:06:51",
      DataValue: "0.08776999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:11:45",
      SrcValue: "92.074",
      DataTime: "2023-01-05 17:08:51",
      DataValue: "0.087169",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:13:45",
      SrcValue: "93.511",
      DataTime: "2023-01-05 17:10:53",
      DataValue: "0.08860599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:15:45",
      SrcValue: "93.594",
      DataTime: "2023-01-05 17:12:51",
      DataValue: "0.08868899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:17:45",
      SrcValue: "93.181",
      DataTime: "2023-01-05 17:14:51",
      DataValue: "0.088276",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:19:45",
      SrcValue: "93.075",
      DataTime: "2023-01-05 17:16:53",
      DataValue: "0.08817",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:21:44",
      SrcValue: "92.781",
      DataTime: "2023-01-05 17:18:51",
      DataValue: "0.08787600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:23:45",
      SrcValue: "91.839",
      DataTime: "2023-01-05 17:20:52",
      DataValue: "0.08693400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:25:45",
      SrcValue: "91.780",
      DataTime: "2023-01-05 17:22:52",
      DataValue: "0.08687500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:27:43",
      SrcValue: "92.969",
      DataTime: "2023-01-05 17:24:52",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:29:44",
      SrcValue: "92.746",
      DataTime: "2023-01-05 17:26:51",
      DataValue: "0.087841",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:31:45",
      SrcValue: "93.017",
      DataTime: "2023-01-05 17:28:52",
      DataValue: "0.088112",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:33:45",
      SrcValue: "93.299",
      DataTime: "2023-01-05 17:30:51",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:35:44",
      SrcValue: "92.157",
      DataTime: "2023-01-05 17:32:51",
      DataValue: "0.087252",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:37:41",
      SrcValue: "92.934",
      DataTime: "2023-01-05 17:34:51",
      DataValue: "0.088029",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:39:45",
      SrcValue: "93.841",
      DataTime: "2023-01-05 17:36:51",
      DataValue: "0.08893599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:41:45",
      SrcValue: "92.793",
      DataTime: "2023-01-05 17:38:51",
      DataValue: "0.08788800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:43:44",
      SrcValue: "93.134",
      DataTime: "2023-01-05 17:40:51",
      DataValue: "0.088229",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:45:44",
      SrcValue: "92.805",
      DataTime: "2023-01-05 17:42:51",
      DataValue: "0.0879",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:47:45",
      SrcValue: "92.805",
      DataTime: "2023-01-05 17:44:51",
      DataValue: "0.0879",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:49:44",
      SrcValue: "92.699",
      DataTime: "2023-01-05 17:46:53",
      DataValue: "0.08779400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:51:44",
      SrcValue: "92.569",
      DataTime: "2023-01-05 17:48:51",
      DataValue: "0.08766399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:53:43",
      SrcValue: "93.005",
      DataTime: "2023-01-05 17:50:51",
      DataValue: "0.08809999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:55:45",
      SrcValue: "92.969",
      DataTime: "2023-01-05 17:52:52",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:57:45",
      SrcValue: "92.180",
      DataTime: "2023-01-05 17:54:51",
      DataValue: "0.08727500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 17:59:45",
      SrcValue: "93.817",
      DataTime: "2023-01-05 17:56:51",
      DataValue: "0.08891199999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:01:44",
      SrcValue: "92.946",
      DataTime: "2023-01-05 17:58:51",
      DataValue: "0.08804100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:03:45",
      SrcValue: "93.146",
      DataTime: "2023-01-05 18:00:51",
      DataValue: "0.08824100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:05:45",
      SrcValue: "91.886",
      DataTime: "2023-01-05 18:02:52",
      DataValue: "0.086981",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:07:44",
      SrcValue: "92.451",
      DataTime: "2023-01-05 18:04:51",
      DataValue: "0.08754599999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:09:43",
      SrcValue: "93.170",
      DataTime: "2023-01-05 18:06:51",
      DataValue: "0.08826500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:11:44",
      SrcValue: "92.852",
      DataTime: "2023-01-05 18:08:51",
      DataValue: "0.087947",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:13:45",
      SrcValue: "92.828",
      DataTime: "2023-01-05 18:10:51",
      DataValue: "0.087923",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:15:44",
      SrcValue: "93.040",
      DataTime: "2023-01-05 18:12:51",
      DataValue: "0.08813500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:17:45",
      SrcValue: "93.735",
      DataTime: "2023-01-05 18:14:52",
      DataValue: "0.08882999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:19:44",
      SrcValue: "92.969",
      DataTime: "2023-01-05 18:16:51",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:21:45",
      SrcValue: "93.005",
      DataTime: "2023-01-05 18:18:51",
      DataValue: "0.08809999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:23:45",
      SrcValue: "93.452",
      DataTime: "2023-01-05 18:20:51",
      DataValue: "0.08854699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:25:43",
      SrcValue: "93.429",
      DataTime: "2023-01-05 18:22:51",
      DataValue: "0.08852399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:27:45",
      SrcValue: "93.299",
      DataTime: "2023-01-05 18:24:51",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:29:45",
      SrcValue: "93.759",
      DataTime: "2023-01-05 18:26:51",
      DataValue: "0.08885400000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:31:41",
      SrcValue: "92.734",
      DataTime: "2023-01-05 18:28:51",
      DataValue: "0.08782899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:33:44",
      SrcValue: "93.052",
      DataTime: "2023-01-05 18:30:51",
      DataValue: "0.088147",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:35:45",
      SrcValue: "92.875",
      DataTime: "2023-01-05 18:32:51",
      DataValue: "0.08796999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:37:45",
      SrcValue: "92.969",
      DataTime: "2023-01-05 18:34:52",
      DataValue: "0.088064",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:39:45",
      SrcValue: "93.335",
      DataTime: "2023-01-05 18:36:51",
      DataValue: "0.08843000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:41:44",
      SrcValue: "93.370",
      DataTime: "2023-01-05 18:38:51",
      DataValue: "0.08846500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:43:44",
      SrcValue: "93.087",
      DataTime: "2023-01-05 18:40:52",
      DataValue: "0.08818200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:45:45",
      SrcValue: "92.628",
      DataTime: "2023-01-05 18:42:51",
      DataValue: "0.087723",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:47:43",
      SrcValue: "92.816",
      DataTime: "2023-01-05 18:44:51",
      DataValue: "0.08791100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:49:45",
      SrcValue: "93.205",
      DataTime: "2023-01-05 18:46:51",
      DataValue: "0.08829999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:51:44",
      SrcValue: "92.816",
      DataTime: "2023-01-05 18:48:51",
      DataValue: "0.08791100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:53:43",
      SrcValue: "93.370",
      DataTime: "2023-01-05 18:50:52",
      DataValue: "0.08846500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:55:45",
      SrcValue: "92.793",
      DataTime: "2023-01-05 18:52:51",
      DataValue: "0.08788800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:57:45",
      SrcValue: "94.112",
      DataTime: "2023-01-05 18:54:53",
      DataValue: "0.08920700000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 18:59:41",
      SrcValue: "93.299",
      DataTime: "2023-01-05 18:56:51",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:01:43",
      SrcValue: "92.016",
      DataTime: "2023-01-05 18:58:51",
      DataValue: "0.087111",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:03:45",
      SrcValue: "91.980",
      DataTime: "2023-01-05 19:00:51",
      DataValue: "0.08707500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:05:45",
      SrcValue: "93.099",
      DataTime: "2023-01-05 19:02:52",
      DataValue: "0.088194",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:07:45",
      SrcValue: "92.993",
      DataTime: "2023-01-05 19:04:51",
      DataValue: "0.088088",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:09:45",
      SrcValue: "93.134",
      DataTime: "2023-01-05 19:06:51",
      DataValue: "0.088229",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:11:45",
      SrcValue: "93.335",
      DataTime: "2023-01-05 19:08:52",
      DataValue: "0.08843000000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:13:44",
      SrcValue: "92.710",
      DataTime: "2023-01-05 19:10:51",
      DataValue: "0.087805",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:15:45",
      SrcValue: "92.863",
      DataTime: "2023-01-05 19:12:51",
      DataValue: "0.08795800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:17:45",
      SrcValue: "93.676",
      DataTime: "2023-01-05 19:14:52",
      DataValue: "0.08877100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:19:44",
      SrcValue: "92.722",
      DataTime: "2023-01-05 19:16:51",
      DataValue: "0.087817",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:21:44",
      SrcValue: "92.239",
      DataTime: "2023-01-05 19:18:51",
      DataValue: "0.087334",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:23:45",
      SrcValue: "92.863",
      DataTime: "2023-01-05 19:20:52",
      DataValue: "0.08795800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:25:45",
      SrcValue: "92.840",
      DataTime: "2023-01-05 19:22:51",
      DataValue: "0.08793500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:27:45",
      SrcValue: "92.286",
      DataTime: "2023-01-05 19:24:51",
      DataValue: "0.08738100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:29:45",
      SrcValue: "92.805",
      DataTime: "2023-01-05 19:26:51",
      DataValue: "0.0879",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:31:45",
      SrcValue: "92.416",
      DataTime: "2023-01-05 19:28:51",
      DataValue: "0.087511",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:33:44",
      SrcValue: "92.333",
      DataTime: "2023-01-05 19:30:51",
      DataValue: "0.087428",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:35:45",
      SrcValue: "92.757",
      DataTime: "2023-01-05 19:32:53",
      DataValue: "0.08785200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:37:44",
      SrcValue: "92.781",
      DataTime: "2023-01-05 19:34:53",
      DataValue: "0.08787600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:39:45",
      SrcValue: "92.699",
      DataTime: "2023-01-05 19:36:51",
      DataValue: "0.08779400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:41:45",
      SrcValue: "92.852",
      DataTime: "2023-01-05 19:38:52",
      DataValue: "0.087947",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:43:43",
      SrcValue: "92.946",
      DataTime: "2023-01-05 19:40:52",
      DataValue: "0.08804100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:45:44",
      SrcValue: "93.393",
      DataTime: "2023-01-05 19:42:52",
      DataValue: "0.08848800000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:47:45",
      SrcValue: "92.581",
      DataTime: "2023-01-05 19:44:51",
      DataValue: "0.087676",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:49:44",
      SrcValue: "93.040",
      DataTime: "2023-01-05 19:46:51",
      DataValue: "0.08813500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:51:45",
      SrcValue: "93.229",
      DataTime: "2023-01-05 19:48:51",
      DataValue: "0.08832400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:53:45",
      SrcValue: "92.840",
      DataTime: "2023-01-05 19:50:51",
      DataValue: "0.08793500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:55:44",
      SrcValue: "92.699",
      DataTime: "2023-01-05 19:52:52",
      DataValue: "0.08779400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:57:45",
      SrcValue: "93.641",
      DataTime: "2023-01-05 19:54:51",
      DataValue: "0.08873600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 19:59:45",
      SrcValue: "93.229",
      DataTime: "2023-01-05 19:56:51",
      DataValue: "0.08832400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:01:45",
      SrcValue: "93.959",
      DataTime: "2023-01-05 19:58:53",
      DataValue: "0.089054",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:03:45",
      SrcValue: "92.875",
      DataTime: "2023-01-05 20:00:51",
      DataValue: "0.08796999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:05:45",
      SrcValue: "92.722",
      DataTime: "2023-01-05 20:02:51",
      DataValue: "0.087817",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:07:45",
      SrcValue: "93.193",
      DataTime: "2023-01-05 20:04:53",
      DataValue: "0.088288",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:09:44",
      SrcValue: "93.841",
      DataTime: "2023-01-05 20:06:51",
      DataValue: "0.08893599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:11:44",
      SrcValue: "91.968",
      DataTime: "2023-01-05 20:08:52",
      DataValue: "0.087063",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:13:44",
      SrcValue: "93.759",
      DataTime: "2023-01-05 20:10:51",
      DataValue: "0.08885400000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:15:45",
      SrcValue: "93.064",
      DataTime: "2023-01-05 20:12:51",
      DataValue: "0.08815899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:17:45",
      SrcValue: "94.171",
      DataTime: "2023-01-05 20:14:51",
      DataValue: "0.08926600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:19:41",
      SrcValue: "92.675",
      DataTime: "2023-01-05 20:16:51",
      DataValue: "0.08776999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:21:45",
      SrcValue: "92.852",
      DataTime: "2023-01-05 20:18:51",
      DataValue: "0.087947",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:23:45",
      SrcValue: "93.664",
      DataTime: "2023-01-05 20:20:51",
      DataValue: "0.088759",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:25:45",
      SrcValue: "92.651",
      DataTime: "2023-01-05 20:22:52",
      DataValue: "0.08774599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:27:45",
      SrcValue: "93.017",
      DataTime: "2023-01-05 20:24:51",
      DataValue: "0.088112",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:29:45",
      SrcValue: "92.569",
      DataTime: "2023-01-05 20:26:51",
      DataValue: "0.08766399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:31:45",
      SrcValue: "93.452",
      DataTime: "2023-01-05 20:28:51",
      DataValue: "0.08854699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:33:45",
      SrcValue: "92.310",
      DataTime: "2023-01-05 20:30:52",
      DataValue: "0.08740500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:35:44",
      SrcValue: "94.053",
      DataTime: "2023-01-05 20:32:51",
      DataValue: "0.089148",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:37:44",
      SrcValue: "93.028",
      DataTime: "2023-01-05 20:34:51",
      DataValue: "0.088123",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:39:45",
      SrcValue: "92.651",
      DataTime: "2023-01-05 20:36:51",
      DataValue: "0.08774599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:41:45",
      SrcValue: "93.299",
      DataTime: "2023-01-05 20:38:51",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:43:45",
      SrcValue: "93.523",
      DataTime: "2023-01-05 20:40:51",
      DataValue: "0.088618",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:45:44",
      SrcValue: "93.382",
      DataTime: "2023-01-05 20:42:52",
      DataValue: "0.088477",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:47:43",
      SrcValue: "92.121",
      DataTime: "2023-01-05 20:44:51",
      DataValue: "0.08721599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:49:45",
      SrcValue: "92.875",
      DataTime: "2023-01-05 20:46:51",
      DataValue: "0.08796999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:51:45",
      SrcValue: "92.357",
      DataTime: "2023-01-05 20:48:53",
      DataValue: "0.087452",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:53:44",
      SrcValue: "92.604",
      DataTime: "2023-01-05 20:50:51",
      DataValue: "0.087699",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:55:45",
      SrcValue: "92.840",
      DataTime: "2023-01-05 20:52:51",
      DataValue: "0.08793500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:57:45",
      SrcValue: "94.206",
      DataTime: "2023-01-05 20:54:51",
      DataValue: "0.08930100000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 20:59:45",
      SrcValue: "93.299",
      DataTime: "2023-01-05 20:56:51",
      DataValue: "0.088394",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:01:45",
      SrcValue: "92.934",
      DataTime: "2023-01-05 20:58:51",
      DataValue: "0.088029",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:03:45",
      SrcValue: "93.417",
      DataTime: "2023-01-05 21:00:51",
      DataValue: "0.08851200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:05:45",
      SrcValue: "92.781",
      DataTime: "2023-01-05 21:02:53",
      DataValue: "0.08787600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:07:45",
      SrcValue: "92.769",
      DataTime: "2023-01-05 21:04:53",
      DataValue: "0.087864",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:09:44",
      SrcValue: "93.064",
      DataTime: "2023-01-05 21:06:51",
      DataValue: "0.08815899999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:11:45",
      SrcValue: "93.005",
      DataTime: "2023-01-05 21:08:51",
      DataValue: "0.08809999999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:13:45",
      SrcValue: "92.498",
      DataTime: "2023-01-05 21:10:51",
      DataValue: "0.087593",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:15:45",
      SrcValue: "97.904",
      DataTime: "2023-01-05 21:12:51",
      DataValue: "0.092999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:17:43",
      SrcValue: "97.645",
      DataTime: "2023-01-05 21:14:51",
      DataValue: "0.09273999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:19:44",
      SrcValue: "97.610",
      DataTime: "2023-01-05 21:16:53",
      DataValue: "0.09270500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:21:45",
      SrcValue: "97.351",
      DataTime: "2023-01-05 21:18:52",
      DataValue: "0.092446",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:23:45",
      SrcValue: "97.869",
      DataTime: "2023-01-05 21:20:51",
      DataValue: "0.09296399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:25:42",
      SrcValue: "97.551",
      DataTime: "2023-01-05 21:22:53",
      DataValue: "0.092646",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:27:45",
      SrcValue: "96.856",
      DataTime: "2023-01-05 21:24:51",
      DataValue: "0.091951",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:29:42",
      SrcValue: "97.374",
      DataTime: "2023-01-05 21:26:51",
      DataValue: "0.092469",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:31:45",
      SrcValue: "97.433",
      DataTime: "2023-01-05 21:28:51",
      DataValue: "0.092528",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:33:45",
      SrcValue: "97.586",
      DataTime: "2023-01-05 21:30:51",
      DataValue: "0.09268100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:35:44",
      SrcValue: "97.598",
      DataTime: "2023-01-05 21:32:51",
      DataValue: "0.092693",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:37:44",
      SrcValue: "97.351",
      DataTime: "2023-01-05 21:34:51",
      DataValue: "0.092446",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:39:45",
      SrcValue: "97.304",
      DataTime: "2023-01-05 21:36:51",
      DataValue: "0.09239900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:41:44",
      SrcValue: "97.622",
      DataTime: "2023-01-05 21:38:52",
      DataValue: "0.092717",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:43:45",
      SrcValue: "97.527",
      DataTime: "2023-01-05 21:40:51",
      DataValue: "0.09262200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:45:43",
      SrcValue: "98.328",
      DataTime: "2023-01-05 21:42:51",
      DataValue: "0.093423",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:47:44",
      SrcValue: "97.516",
      DataTime: "2023-01-05 21:44:51",
      DataValue: "0.092611",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:49:44",
      SrcValue: "97.492",
      DataTime: "2023-01-05 21:46:51",
      DataValue: "0.092587",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:51:45",
      SrcValue: "97.622",
      DataTime: "2023-01-05 21:48:51",
      DataValue: "0.092717",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:53:44",
      SrcValue: "97.951",
      DataTime: "2023-01-05 21:50:52",
      DataValue: "0.09304599999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:55:45",
      SrcValue: "97.386",
      DataTime: "2023-01-05 21:52:51",
      DataValue: "0.09248100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:57:45",
      SrcValue: "98.093",
      DataTime: "2023-01-05 21:54:51",
      DataValue: "0.093188",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 21:59:43",
      SrcValue: "97.551",
      DataTime: "2023-01-05 21:56:51",
      DataValue: "0.092646",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:01:44",
      SrcValue: "97.539",
      DataTime: "2023-01-05 21:58:53",
      DataValue: "0.092634",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:03:45",
      SrcValue: "97.869",
      DataTime: "2023-01-05 22:00:51",
      DataValue: "0.09296399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:05:45",
      SrcValue: "97.574",
      DataTime: "2023-01-05 22:02:51",
      DataValue: "0.092669",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:07:45",
      SrcValue: "97.468",
      DataTime: "2023-01-05 22:04:51",
      DataValue: "0.092563",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:09:43",
      SrcValue: "97.386",
      DataTime: "2023-01-05 22:06:51",
      DataValue: "0.09248100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:11:44",
      SrcValue: "98.128",
      DataTime: "2023-01-05 22:08:51",
      DataValue: "0.093223",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:13:44",
      SrcValue: "97.810",
      DataTime: "2023-01-05 22:10:53",
      DataValue: "0.09290500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:15:44",
      SrcValue: "97.527",
      DataTime: "2023-01-05 22:12:51",
      DataValue: "0.09262200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:17:40",
      SrcValue: "97.610",
      DataTime: "2023-01-05 22:14:51",
      DataValue: "0.09270500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:19:45",
      SrcValue: "97.539",
      DataTime: "2023-01-05 22:16:51",
      DataValue: "0.092634",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:21:43",
      SrcValue: "97.622",
      DataTime: "2023-01-05 22:18:51",
      DataValue: "0.092717",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:23:45",
      SrcValue: "95.996",
      DataTime: "2023-01-05 22:20:51",
      DataValue: "0.091091",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:25:44",
      SrcValue: "97.315",
      DataTime: "2023-01-05 22:22:52",
      DataValue: "0.09240999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:27:43",
      SrcValue: "97.504",
      DataTime: "2023-01-05 22:24:51",
      DataValue: "0.09259900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:29:44",
      SrcValue: "97.162",
      DataTime: "2023-01-05 22:26:51",
      DataValue: "0.092257",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:31:45",
      SrcValue: "96.079",
      DataTime: "2023-01-05 22:28:52",
      DataValue: "0.091174",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:33:45",
      SrcValue: "97.233",
      DataTime: "2023-01-05 22:30:51",
      DataValue: "0.092328",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:35:44",
      SrcValue: "97.233",
      DataTime: "2023-01-05 22:32:51",
      DataValue: "0.092328",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:37:45",
      SrcValue: "97.421",
      DataTime: "2023-01-05 22:34:51",
      DataValue: "0.09251600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:39:45",
      SrcValue: "97.421",
      DataTime: "2023-01-05 22:36:53",
      DataValue: "0.09251600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:41:43",
      SrcValue: "97.410",
      DataTime: "2023-01-05 22:38:51",
      DataValue: "0.092505",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:43:43",
      SrcValue: "97.728",
      DataTime: "2023-01-05 22:40:52",
      DataValue: "0.09282299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:45:45",
      SrcValue: "97.280",
      DataTime: "2023-01-05 22:42:53",
      DataValue: "0.09237500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:47:45",
      SrcValue: "97.586",
      DataTime: "2023-01-05 22:44:51",
      DataValue: "0.09268100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:49:44",
      SrcValue: "97.586",
      DataTime: "2023-01-05 22:46:51",
      DataValue: "0.09268100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:51:43",
      SrcValue: "97.268",
      DataTime: "2023-01-05 22:48:51",
      DataValue: "0.092363",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:53:44",
      SrcValue: "97.398",
      DataTime: "2023-01-05 22:50:53",
      DataValue: "0.09249299999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:55:45",
      SrcValue: "97.292",
      DataTime: "2023-01-05 22:52:51",
      DataValue: "0.092387",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:57:45",
      SrcValue: "97.351",
      DataTime: "2023-01-05 22:54:54",
      DataValue: "0.092446",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 22:59:45",
      SrcValue: "96.762",
      DataTime: "2023-01-05 22:56:51",
      DataValue: "0.091857",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:01:45",
      SrcValue: "98.246",
      DataTime: "2023-01-05 22:58:51",
      DataValue: "0.09334100000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:03:45",
      SrcValue: "97.480",
      DataTime: "2023-01-05 23:00:52",
      DataValue: "0.09257500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:05:44",
      SrcValue: "97.315",
      DataTime: "2023-01-05 23:02:51",
      DataValue: "0.09240999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:07:44",
      SrcValue: "97.362",
      DataTime: "2023-01-05 23:04:51",
      DataValue: "0.09245699999999998",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:09:45",
      SrcValue: "97.139",
      DataTime: "2023-01-05 23:06:51",
      DataValue: "0.09223400000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:11:45",
      SrcValue: "97.563",
      DataTime: "2023-01-05 23:08:51",
      DataValue: "0.09265800000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:13:44",
      SrcValue: "97.092",
      DataTime: "2023-01-05 23:10:51",
      DataValue: "0.09218699999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:15:45",
      SrcValue: "97.598",
      DataTime: "2023-01-05 23:12:51",
      DataValue: "0.092693",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:17:45",
      SrcValue: "97.539",
      DataTime: "2023-01-05 23:14:52",
      DataValue: "0.092634",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:19:45",
      SrcValue: "97.504",
      DataTime: "2023-01-05 23:16:51",
      DataValue: "0.09259900000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:21:44",
      SrcValue: "97.221",
      DataTime: "2023-01-05 23:18:51",
      DataValue: "0.09231600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:23:44",
      SrcValue: "97.516",
      DataTime: "2023-01-05 23:20:51",
      DataValue: "0.092611",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:25:45",
      SrcValue: "97.987",
      DataTime: "2023-01-05 23:22:51",
      DataValue: "0.093082",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:27:44",
      SrcValue: "97.339",
      DataTime: "2023-01-05 23:24:51",
      DataValue: "0.09243399999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:29:44",
      SrcValue: "97.633",
      DataTime: "2023-01-05 23:26:51",
      DataValue: "0.092728",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:31:45",
      SrcValue: "96.597",
      DataTime: "2023-01-05 23:28:51",
      DataValue: "0.091692",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:33:44",
      SrcValue: "97.315",
      DataTime: "2023-01-05 23:30:52",
      DataValue: "0.09240999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:35:45",
      SrcValue: "97.516",
      DataTime: "2023-01-05 23:32:51",
      DataValue: "0.092611",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:37:45",
      SrcValue: "97.551",
      DataTime: "2023-01-05 23:34:53",
      DataValue: "0.092646",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:39:42",
      SrcValue: "97.645",
      DataTime: "2023-01-05 23:36:51",
      DataValue: "0.09273999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:41:45",
      SrcValue: "97.351",
      DataTime: "2023-01-05 23:38:52",
      DataValue: "0.092446",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:43:45",
      SrcValue: "97.610",
      DataTime: "2023-01-05 23:40:51",
      DataValue: "0.09270500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:45:45",
      SrcValue: "97.280",
      DataTime: "2023-01-05 23:42:51",
      DataValue: "0.09237500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:47:45",
      SrcValue: "96.774",
      DataTime: "2023-01-05 23:44:51",
      DataValue: "0.091869",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:49:45",
      SrcValue: "97.610",
      DataTime: "2023-01-05 23:46:52",
      DataValue: "0.09270500000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:51:45",
      SrcValue: "98.611",
      DataTime: "2023-01-05 23:48:53",
      DataValue: "0.09370600000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:53:45",
      SrcValue: "96.255",
      DataTime: "2023-01-05 23:50:53",
      DataValue: "0.09134999999999999",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:55:41",
      SrcValue: "97.527",
      DataTime: "2023-01-05 23:52:51",
      DataValue: "0.09262200000000001",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:57:44",
      SrcValue: "97.480",
      DataTime: "2023-01-05 23:54:52",
      DataValue: "0.09257500000000002",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-21 23:59:45",
      SrcValue: "96.656",
      DataTime: "2023-01-05 23:56:51",
      DataValue: "0.091751",
      DataStatus: [],
    },
    {
      CorpID: "4",
      MonitorPointID: "72",
      SignalID: "72",
      RecordType: 0,
      SrcTime: "2022-10-22 00:01:44",
      SrcValue: "97.504",
      DataTime: "2023-01-05 23:58:52",
      DataValue: "0.09259900000000001",
      DataStatus: [],
    },
  ],
  Extras: null,
  Timestamp: "2023-01-06 17:16:28",
};

export default {
  name: "vibration",
  components: {
    titleBoxVue,
    leftTree,
    queryDisabled:false,
    daterange:'',
    pickerOptions: {
        disabledDate(time) {
          return time.getTime() > Date.now();
        },
      },
  },
  data() {
    return {
      chartData: [],
      checkObj: null,
      /**是否是故障分析 */
      isGuZhangFenXi: false,
    };
  },
  created() {},
  mounted() {
    setTimeout(() => {
      // this.initChart();
      this.initialChartOfValue(testData.Data);
    }, 200);

    window.addEventListener("resize", () => {
      setTimeout(() => {
        m_chartMain && m_chartMain.resize();
      }, 10);
    });
  },
  computed: {
    chartKey() {
      let l = this.chartData.length;
      let key = this.isGuZhangFenXi ? l + "_1" : l + "_0";
      return key;
    },
  },
  watch: {},
  methods: {
    handleNodeClick(data, obj) {
      console.log(data, obj, 74);
      this.checkObj = obj;
    },
    queryAlarmList() {
      if (!this.daterange) {
        this.$message({
          message: "请选择日期范围",
          type: "warning",
        });
        return;
      }
      console.log(this.daterange, 232);
      if (this.daterange && this.daterange.length) {
        let startdate = this.daterange[0];
        let enddate = this.daterange[1];
        console.log(startdate, enddate, 236);
      }
    },
    initChart() {
      var chartDom = document.getElementById("chartMain");
      m_chartMain = echarts.init(chartDom);
      var series_arr = [];
      var yAxisArr = [];

      var yAxisName = "加速度:g";
      series_arr.push({
        name: "",
        type: "line",
        smooth: true,
        symbolSize: 0,
        sampling: "max",
        itemStyle: {
          normal: {
            lineStyle: {
              width: 1,
            },
            color: "rgb(0, 0, 255)",
          },
        },
        symbolSize: 1,
        data: [],
      });

      yAxisArr = {
        type: "value",
        name: yAxisName,
        nameGap: 35,
        nameLocation: "center",
        // boundaryGap: x.boundaryGap,
        scale: true,
        axisLine: {
          show: true,
        },
      };

      let option = {
        grid: {
          top: 20,
          left: 50,
          right: 50,
          containLabel: true,
        },
        xAxis: {
          name: "",
          type: "category",
          nameLocation: "center",
          axisLine: {
            onZero: false,
          },
          nameGap: 23,
          data: [],
        },
        yAxis: yAxisArr,
        dataZoom: [
          {
            type: "inside",
            start: 0,
            end: 100,
          },
          {
            id: "dataZoomY",
            type: "slider",
            xAxisIndex: [0],
            filterMode: "empty",
          },
        ],

        tooltip: {
          trigger: "axis",
          hideDelay: 1000,
          axisPointer: {
            type: "cross",
          },
          position: function (pt) {
            return [pt[0], "10%"];
          },
        },
        series: series_arr,
      };

      m_chartMain.setOption(option);
    },
    initialChartOfValue(recordList_ds) {
      //console.log(recordList_ds,241)
      if (m_chartMain) {
        m_chartMain.clear();
      }
      m_chartMain = echarts.init(document.getElementById("chartMain"));

      m_unitName = "MPa";
      m_recordName = "压力";

      m_chartRecordList = [];
      m_alarmList = [];
      var series_arr = [];
      var yaxisName = "";
      var legendData = [];
      var tipUnitName = "";
      if (recordList_ds == null || recordList_ds.length == 0) return;

      yaxisName = m_recordName + "(" + m_unitName + ")";
      tipUnitName = m_unitName;
      //console.log(recordList_ds, 243)
      let baseDate =
        new Date(recordList_ds[0].DataTime).getFullYear() +
        "-" +
        (new Date(recordList_ds[0].DataTime).getMonth() + 1) +
        "-" +
        new Date(recordList_ds[0].DataTime).getDate();
    

      var lastTime = null;
      var ignore_time = 1000 * 60 * 10;

      var chart_series_record_arr = [];
      var chart_series_alarm_arr = [];

      m_chartValueSeriesList = [];
      let teShuDian = ["3053", "3054", "3055", "3056", "3057", "3058"];
      var nn = recordList_ds.length;
      for (var i = 0; i < nn; i++) {
        var record = recordList_ds[i];
        var real_time = record.DataTime;
        var real_value = record.DataValue;

        var dataValue = { value: [real_time, real_value] };
        var alarmValue = null;
        if ((record.RecordStatus & 2) == 2) {
          alarmValue = { value: real_value, coord: [real_time, real_value] };
          // m_alarmList.push(alarmValue)
        }

        if (lastTime == null) {
          lastTime = new Date(real_time).getTime();
        }
        if (teShuDian.indexOf(m_currentPointID) != -1) {
          //m_chartValueSeriesList.push({ record: chart_series_record_arr, alarm: chart_series_alarm_arr });
        } else {
          if (new Date(real_time).getTime() - lastTime > ignore_time) {
            if (chart_series_record_arr.length > 3) {
              m_chartValueSeriesList.push({
                record: chart_series_record_arr,
                alarm: chart_series_alarm_arr,
              });
            }
            chart_series_record_arr = [];
            chart_series_alarm_arr = [];
          }
        }

        chart_series_record_arr.push(dataValue);
        if (alarmValue != null) {
          chart_series_alarm_arr.push(alarmValue);
        }

        lastTime = new Date(real_time).getTime();
      }
      m_chartValueSeriesList.push({
        record: chart_series_record_arr,
        alarm: chart_series_alarm_arr,
      });

      var color_curve = "#4169E1";
      let showSymbol = false;
      let min = null;
      let max = null;
      let interval = null;
      if (teShuDian.indexOf(m_currentPointID) != -1) {
        showSymbol = true;
      }
      min = baseDate + " 00:00:00";
      max = baseDate + " 23:59:59";
      interval = 1000 * 60 * 60 * 2;
      //console.log(m_chartValueSeriesList)
      for (var i = 0; i < m_chartValueSeriesList.length; i++) {
        series_arr.push({
          name: m_recordName, 
          type: "line",
          showSymbol: showSymbol,
          hoverAnimation: false,
          data: m_chartValueSeriesList[i].record,
          itemStyle: {
            color: color_curve,
          },
          //markPoint: {
          //    symbolSize: 80,
          //    data: m_chartValueSeriesList[i].alarm
          //},
          //markLine: {
          //    silent: true,
          //    label: {
          //        position: 'end',
          //        //distance: [20,20]
          //    },
          //    data: i == 0 ? markLineData : []
          //}
        });
      }

      var main_chart_option = {
        title: {
          text: "",
        },
        legend: {
          data: legendData,
          top: 30,
          right: 50,
        },
        tooltip: {
          trigger: "axis",
          formatter: function (params) {
            //console.log(params);
            var tip = "";
            var date = new Date(params[0].value[0]);
            tip += date.getHours() + ":" + date.getMinutes() + " <br/>";
            for (var i = 0; i < params.length; i++) {
              var node = params[i];
              if (i == params.length - 1) {
                tip +=
                  node.marker +
                  node.seriesName +
                  "：" +
                  (node.value[1] - 0) +
                  " " +
                  tipUnitName;
              } else {
                tip +=
                  node.marker +
                  node.seriesName +
                  "：" +
                  (node.value[1] - 0) +
                  " " +
                  tipUnitName +
                  " <br/>";
              }
            }
            return tip;
            //var params_record = params[0];
            //var date = new Date(params_record.value[0]);
            //return date.getHours() + ':' + date.getMinutes() + ' <br/>值: ' + (params_record.value[1] - 0) + " " + tipUnitName;
          },
          axisPointer: {
            animation: false,
          },
        },
        grid: {
          containLabel: true,
          x: "25",
          y: "65",
          x2: "30",
          y2: "50",
        },
        toolbox: {
          show: true,
          top: 0,
          right: 40,
          iconStyle: {
            normal: {
              color: "#87CEFA",
            },
          },
          emphasis: {
            //iconStyle: {
            //    textFill: '#fff',
            //    color: '#fff',
            //    borderColor: '#ccc',
            //},
          },
          feature: {
            mark: { show: true },
            dataZoom: {
              show: true,
              yAxisIndex: "none",
            },
            dataView: {
              show: true,
              readOnly: true,
              optionToContent: function (opt) {
                var series_list = opt.series;
                var table =
                  '<table contenteditable="true"><tbody><tr>' +
                  '<td style="padding:2px 30px;text-align:center;">时间</td>' +
                  '<td style="padding:2px 30px;text-align:center;">监控值</td>' +
                  "</tr>";

                for (var i = 0; i < series_list.length; i++) {
                  var series = series_list[i];
                  for (var i = 0, l = series.data.length; i < l; i++) {
                    table +=
                      "<tr>" +
                      '<td  style="padding:2px 30px;text-align:center;">' +
                      series.data[i].value[0] +
                      "</td>" +
                      '<td  style="padding:2px 30px;text-align:center;">' +
                      series.data[i].value[1] +
                      "</td>" +
                      "</tr>";
                  }
                }

                table += "</tbody></table>";
                return table;
              },
            },
            magicType: { show: true, type: ["line", "bar", "stack", "tiled"] },
            restore: { show: true },
            saveAsImage: { name: "picture", show: true },
            // myTool1: {
            //   show: true,
            //   title: "设置Y轴坐标",
            //   icon: "path://M962.92864 602.1888c-9.09824 48.42496-43.42272 80.96256-85.41696 80.96256h-4.8128a54.66624 54.66624 0 0 0-54.0672 55.08096 49.7408 49.7408 0 0 0 2.4576 12.96896q1.08544 3.69664 2.50368 7.2704a100.53632 100.53632 0 0 1-34.78528 122.7776l-3.072 1.9968c-0.54784 0.3584-1.11616 0.70144-1.6896 1.024l-104.14592 58.368a28.672 28.672 0 0 1-2.56 1.2288l-1.024 0.512a100.65408 100.65408 0 0 1-40.61696 8.35072 105.01632 105.01632 0 0 1-75.81184-31.7696 141.89056 141.89056 0 0 0-33.75616-25.72288 26.39872 26.39872 0 0 0-12.288-3.072 23.38304 23.38304 0 0 0-12.17024 3.33312 145.88928 145.88928 0 0 0-33.76128 26.112 104.73984 104.73984 0 0 1-76.31872 32.3328 99.79392 99.79392 0 0 1-39.89504-8.09984l-0.87552-0.35328-3.22048-1.536q-0.88064-0.43008-1.7408-0.9216l-107.8272-59.95008a28.38016 28.38016 0 0 1-2.56-1.64352l-1.024-0.7168a100.52096 100.52096 0 0 1-34.01728-122.46016q1.3312-3.456 2.35008-7.01952a50.04288 50.04288 0 0 0 2.5088-13.02016 54.66624 54.66624 0 0 0-54.04672-55.05536h-4.34688c-42.30656 0-76.8-32.5376-85.888-80.96256a531.18464 531.18464 0 0 1-9.41056-90.50112 520.84736 520.84736 0 0 1 9.46176-90.54208c9.05728-48.41984 43.58144-80.96256 85.98528-80.96256h4.1984A54.66112 54.66112 0 0 0 205.312 285.11744a80.73216 80.73216 0 0 0-4.96128-20.23936 100.6336 100.6336 0 0 1 33.86368-122.15808l0.81408-0.5632 2.9696-1.95072c0.56832-0.3584 1.14688-0.70144 1.7408-1.024l102.16448-57.64608a30.6688 30.6688 0 0 1 2.50368-1.23392l1.024-0.512a99.584 99.584 0 0 1 40.70912-8.46336 103.7568 103.7568 0 0 1 76.88192 33.31072 150.1184 150.1184 0 0 0 35.80416 28.07808 23.35232 23.35232 0 0 0 21.73952 0.1536 148.08064 148.08064 0 0 0 36.46976-28.99968 103.69536 103.69536 0 0 1 77.34272-33.82272 99.6352 99.6352 0 0 1 40.00256 8.192l0.9216 0.41472 3.11808 1.47968q0.86016 0.4352 1.6896 0.92672l105.88672 59.28448a28.55936 28.55936 0 0 1 2.45248 1.536l1.024 0.7168a100.67968 100.67968 0 0 1 34.01728 122.46016c0 0.0512-1.1264 2.82112-2.3552 7.01952a49.92 49.92 0 0 0-2.50368 13.02016 54.67648 54.67648 0 0 0 54.0672 55.08096h4.24448c42.35776 0 76.88704 32.54272 85.9392 80.96256a525.312 525.312 0 0 1 9.46176 90.48576v0.05632a534.3744 534.3744 0 0 1-9.41568 90.50624z m-49.46432-173.92128c-2.96448-15.83104-12.63616-34.35008-30.00832-34.35008h-4.27008a113.96096 113.96096 0 0 1-113.44384-114.176 106.22464 106.22464 0 0 1 4.9408-29.696 133.4016 133.4016 0 0 1 4.94592-14.12096 43.87328 43.87328 0 0 0-14.15168-52.40832l-0.26112-0.1536-0.2048-0.1536-106.74176-59.33568-0.2048-0.1536-0.26112-0.10752a47.77984 47.77984 0 0 0-52.0192 11.72992c-16.69632 18.36544-57.2672 53.13536-91.5456 53.13536-13.824 0-31.05792-6.22592-49.664-18.00704a213.08928 213.08928 0 0 1-41.20576-34.11968 47.77984 47.77984 0 0 0-52.1728-11.3152l-0.256 0.1024-0.20992 0.1536-102.99392 57.94304-0.20992 0.10752-0.26112 0.2048a43.99616 43.99616 0 0 0-14.10048 52.40832 142.47424 142.47424 0 0 1 4.9408 14.12096 105.6256 105.6256 0 0 1 4.9408 29.696 113.98656 113.98656 0 0 1-113.50016 114.176h-4.34688c-17.26976 0.1024-26.89024 18.57536-29.85472 34.35008a466.432 466.432 0 0 0-8.58624 80.896 466.8672 466.8672 0 0 0 8.58624 80.95232c2.96448 15.82592 12.58496 34.35008 29.90592 34.35008h4.352a113.96096 113.96096 0 0 1 113.44896 114.176 105.3952 105.3952 0 0 1-4.9408 29.696 117.02784 117.02784 0 0 1-4.9408 14.11072 43.84256 43.84256 0 0 0 14.20288 52.41344l0.26112 0.1536 0.26112 0.15872 108.544 60.0832 0.256 0.10752 0.31232 0.1024a48.71168 48.71168 0 0 0 52.0192-11.15648c16.384-17.3312 56.22784-50.0224 89.46688-50.0224 32.97792 0 72.61696 32.06656 88.94464 49.03936a48.7936 48.7936 0 0 0 52.17792 10.79296l0.20992-0.1024 0.256-0.15872 104.86272-58.68544 0.26112-0.15872 0.20992-0.1536a43.93984 43.93984 0 0 0 14.14656-52.41344 142.18752 142.18752 0 0 1-4.992-14.11072 107.33056 107.33056 0 0 1-4.8896-29.696 113.98144 113.98144 0 0 1 113.49504-114.176h4.7872c10.61376 0 24.65792-8.97536 29.44512-34.35008h0.04608a478.67392 478.67392 0 0 0 8.58624-80.896 466.65216 466.65216 0 0 0-8.576-80.98304z m-203.8784 142.848a23.95136 23.95136 0 0 1-1.024 8.75008 189.58336 189.58336 0 0 1-73.07264 95.38048 185.856 185.856 0 0 1-107.28448 34.03264 189.48608 189.48608 0 0 1-178.51904-128.8448 24.15104 24.15104 0 0 1-1.024-7.59808 192.12288 192.12288 0 0 1 4.37248-124.21632 24.09472 24.09472 0 0 1 1.39776-6.82496 188.928 188.928 0 0 1 173.76768-116.49024 185.344 185.344 0 0 1 79.04768 17.664 189.29664 189.29664 0 0 1 96.54784 98.9952 23.94112 23.94112 0 0 1 1.536 8.38656 194.41152 194.41152 0 0 1 4.25472 120.75008z m-179.8656-196.98176a142.94016 142.94016 0 1 0 68.29056 267.89888 144.60928 144.60928 0 0 0-26.84416-261.57568 140.98944 140.98944 0 0 0-41.4464-6.33856z",
            //   onclick: setChartyAxis,
            // },
          },
        },
        dataZoom: [
          {
            id: "dataZoomX",
            type: "slider",
            xAxisIndex: [0],
            start: 0,
            end: 100,
            bottom: 10,
            filterMode: "filter",
            handleIcon:
              "M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4v1.3h1.3v-1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7V23h6.6V24.4z M13.3,19.6H6.7v-1.4h6.6V19.6z",
            handleSize: "80%",
            handleStyle: {
              color: "#fff",
              shadowBlur: 3,
              shadowColor: "rgba(0, 0, 0, 0.9)", //rgba(0, 0, 0, 0.9)
              shadowOffsetX: 2,
              shadowOffsetY: 2,
            },
            backgroundColor: "#eee",
            borderColor: "#ccc",
            dataBackground: {
              lineStyle: {
                //color:'red',
              },
            },
          },
          {
            // 这个dataZoom组件，也控制x轴。
            type: "inside", // 这个 dataZoom 组件是 inside 型 dataZoom 组件
            start: 0, // 左边在 24% 的位置。
            end: 100, // 右边在 100% 的位置。
          },
        ],
        xAxis: {
          type: "time",
          splitLine: {
            show: true,
            lineStyle: {
              type: "dashed",
            },
          },
          axisLabel: {
            //color: '#fff',
            formatter: function (v, index) {
              //.log(value, index);
              var date = new Date(v);
              //console.log(date);
              var texts = [date.getHours(), date.getMinutes()];
              //var texts = [date.getHours(),"00"];
              return texts.join(":");
            },
          },
          axisLine: {
            lineStyle: {
              // color: '#fff'
            },
          },
          min: min,
          max: max,
          interval: interval,
        },
        yAxis: {
          name: yaxisName,
          nameLocation: "end",
          nameTextStyle: {
            align: "left",
          },
          type: "value",
          boundaryGap: [0, "100%"],
          splitLine: {
            show: true,
            lineStyle: {
              type: "dashed",
            },
          },
          axisLabel: {
            //color: '#fff',
          },
          axisLine: {
            lineStyle: {
              //color: '#fff'
            },
          },
          scale: true,
        },
        series: series_arr,
      };

      m_chartMain.setOption(main_chart_option);
    },
  },
};
</script>
<style scoped>
.boxright {
  flex: 1;
  height: 100%;
  overflow: auto;
  background: #fff;
  margin-left: 20px;
}
.chartbox {
  width: 100%;
  height: 100%;
}
.titleBoxRightSlot {
  display: flex;
  align-items: center;
  justify-content: flex-start;
  margin-left: 40px;
}
</style>